@@ -2,7 +2,7 @@
  * vlc_input_item.h: Core input item
  *****************************************************************************
  * Copyright (C) 1999-2009 VLC authors and VideoLAN
- * $Id: 24d67871d6c9d0ce1c96a0babb6735f54766584f $
+ * $Id: d820a9fc950d569bf0be16d9bc70122cd96067ae $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Laurent Aimar <fenrir@via.ecp.fr>
@@ -173,18 +173,6 @@ struct input_item_node_t
 VLC_API void input_item_CopyOptions( input_item_t *p_child, input_item_t *p_parent );
 VLC_API void input_item_SetName( input_item_t *p_item, const char *psz_name );
 
-/**
- * Add one subitem to this item
- *
- * This won't hold the item, but can tell to interested third parties
- * Like the playlist, that there is a new sub item. With this design
- * It is not the input item's responsibility to keep all the ref of
- * the input item children.
- *
- * Sends a vlc_InputItemSubItemTreeAdded event
- */
-VLC_API void input_item_PostSubItem( input_item_t *p_parent, input_item_t *p_child );
-
 /**
  * Start adding multiple subitems.
  *
@@ -213,18 +201,6 @@ void input_item_node_RemoveNode( input_item_node_t *parent,
  */
 VLC_API void input_item_node_Delete( input_item_node_t *p_node );
 
-/**
- * End adding multiple subitems.
- *
- * Sends a vlc_InputItemSubItemTreeAdded event to notify that the item pointed to
- * by the given root node has created new subitems that are pointed to by all the
- * children of the node.
- *
- * In the end deletes the node and all its children nodes.
- */
-VLC_API void input_item_node_PostAndDelete( input_item_node_t *p_node );
-
-
 /**
  * Option flags
  */
