@@ -3,7 +3,7 @@
  *****************************************************************************
  * Copyright (C) 2005-2010 VLC authors and VideoLAN
  *
- * $Id: 3fcde1091c165d8362a421eadc101e9c3259fcc6 $
+ * $Id: fbb99fbaf43a342ac252b79be127bc884cf8ddec $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Filippo Carone <littlejohn@videolan.org>
@@ -39,7 +39,7 @@
 #include <vlc_input.h>
 #include <vlc_vout.h>
 
-#include <libvlc_internal.h>
+#include "libvlc_internal.h"
 #include "media_player_internal.h"
 #include <math.h>
 #include <assert.h>
