@@ -993,7 +993,6 @@ static es_out_id_t *esOutAdd(es_out_t *p_out, const es_format_t *p_fmt)
     es_format_t fmt;
     bool b_select = false;
 
-    es_format_Init(&fmt, p_fmt->i_cat, p_fmt->i_codec);
     es_format_Copy(&fmt, p_fmt);
 
     switch (fmt.i_cat) {
@@ -1921,17 +1920,15 @@ static int blurayControl(demux_t *p_demux, int query, va_list args)
         else if (meta->thumb_count > 0 && meta->thumbnails && p_sys->psz_bd_path) {
             char *psz_thumbpath;
             if (asprintf(&psz_thumbpath, "%s" DIR_SEP "BDMV" DIR_SEP "META" DIR_SEP "DL" DIR_SEP "%s",
-                          p_sys->psz_bd_path, meta->thumbnails[0].path) > 0) {
+                          p_sys->psz_bd_path, meta->thumbnails[0].path) > -1) {
                 char *psz_thumburl = vlc_path2uri(psz_thumbpath, "file");
-                if (unlikely(psz_thumburl == NULL)) {
-                    free(psz_thumbpath);
+                free(psz_thumbpath);
+                if (unlikely(psz_thumburl == NULL))
                     return VLC_ENOMEM;
-                }
 
                 vlc_meta_SetArtURL(p_meta, psz_thumburl);
                 free(psz_thumburl);
             }
-            free(psz_thumbpath);
         }
 
         return VLC_SUCCESS;
