@@ -2,7 +2,7 @@
  * dshow.cpp : DirectShow access and access_demux module for vlc
  *****************************************************************************
  * Copyright (C) 2002-2004, 2006, 2008, 2010 the VideoLAN team
- * $Id: d16efba490f3827e03a00a94f6e0c9932c18a3a7 $
+ * $Id: d3dd1a42242e6db6342c6b8d2776ae8ff9ce6262 $
  *
  * Author: Gildas Bazin <gbazin@videolan.org>
  *         Damien Fouilleul <damienf@videolan.org>
@@ -476,8 +476,7 @@ static int CommonOpen( vlc_object_t *p_this, access_sys_t *p_sys,
 
     /* Chroma */
     psz_val = var_CreateGetString( p_this, CFG_PREFIX "chroma" );
-    i_chroma = vlc_fourcc_GetCodecFromString( UNKNOWN_ES, psz_val );
-    p_sys->b_chroma = i_chroma != 0;
+    i_chroma = vlc_fourcc_GetCodecFromString( VIDEO_ES, psz_val );
     free( psz_val );
 
     var_Create( p_this, CFG_PREFIX "fps", VLC_VAR_FLOAT | VLC_VAR_DOINHERIT );
@@ -2049,7 +2048,9 @@ static int FindDevices( vlc_object_t *p_this, const char *psz_name,
     {
         bool b_audio = !strcmp( psz_name, CFG_PREFIX "adev" );
 
-        ComContext ctx( COINIT_MULTITHREADED );
+        // Use STA as this most likely comes from a Qt thread, which is
+        // initialized as STA.
+        ComContext ctx( COINIT_APARTMENTTHREADED );
 
         FindCaptureDevice( p_this, NULL, &list_devices, b_audio );
 
