@@ -2,7 +2,7 @@
  * dv.c: Digital video/Firewire input (file: access plug-in)
  *****************************************************************************
  * Copyright (C) 2005 M2X
- * $Id: d81d2b6659b11491344136cc47b007b0fec511ae $
+ * $Id: 7af5e058fd9a8ac1cca7b2ab486b00237bb5590e $
  *
  * Authors: Jean-Paul Saman <jpsaman at m2x dot nl>
  *
@@ -128,7 +128,7 @@ static int Open( vlc_object_t *p_this )
     /* Set up p_access */
     ACCESS_SET_CALLBACKS( NULL, Block, Control, NULL );
 
-    p_access->p_sys = p_sys = malloc( sizeof( access_sys_t ) );
+    p_access->p_sys = p_sys = vlc_malloc( p_this, sizeof( access_sys_t ) );
     if( !p_sys )
         return VLC_EGENERIC;
 
@@ -259,7 +259,6 @@ static void Close( vlc_object_t *p_this )
     AVCClose( p_access );
 
     vlc_mutex_destroy( &p_sys->lock );
-    free( p_sys );
 }
 
 /*****************************************************************************
