@@ -2,7 +2,7 @@
  * mmstu.c: MMS access plug-in
  *****************************************************************************
  * Copyright (C) 2001, 2002 VLC authors and VideoLAN
- * $Id: d694fd6da13b17ee057b1b8f8cfa4e2b7ccaff69 $
+ * $Id: a3a0425b694d573777f4e7a8c3695e360247fc8b $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -490,7 +490,6 @@ static int MMSOpen( access_t  *p_access, vlc_url_t *p_url, int  i_proto )
     uint32_t     i_tool_version;
     uint32_t     i_update_player_url;
     uint32_t     i_encryption_type;
-    int          i;
     int          i_streams;
     int          i_first;
     char         *mediapath;
@@ -843,7 +842,7 @@ static int MMSOpen( access_t  *p_access, vlc_url_t *p_url, int  i_proto )
     i_first = -1;
     var_buffer_reinitwrite( &buffer, 0 );
     /* for now, select first audio and video stream */
-    for( i = 1; i < 128; i++ )
+    for( int i = 1; i < 128; i++ )
     {
 
         if( p_sys->asfh.stream[i].i_cat != ASF_CODEC_TYPE_UNKNOWN )
