@@ -2,7 +2,7 @@
  * sftp.c: SFTP input module
  *****************************************************************************
  * Copyright (C) 2009 VLC authors and VideoLAN
- * $Id: fc5e529787a7f4462e63d1d16effca3374b55d00 $
+ * $Id: f43975dfd8f94e63be80c990d0e762d819e3a3dc $
  *
  * Authors: Rémi Duraffort <ivoire@videolan.org>
  *          Petri Hintukainen <phintuka@gmail.com>
@@ -197,7 +197,7 @@ static int Open( vlc_object_t* p_this )
     if( !p_access->psz_location )
         return VLC_EGENERIC;
 
-    p_sys = p_access->p_sys = (access_sys_t*)calloc( 1, sizeof( access_sys_t ) );
+    p_sys = p_access->p_sys = vlc_calloc( p_this, 1, sizeof( access_sys_t ) );
     if( !p_sys ) return VLC_ENOMEM;
 
     p_sys->i_socket = -1;
@@ -452,7 +452,6 @@ static void Close( vlc_object_t* p_this )
         net_Close( p_sys->i_socket );
 
     free( p_sys->psz_base_url );
-    free( p_sys );
 }
 
 
