@@ -2,7 +2,7 @@
  * araw.c: Pseudo audio decoder; for raw pcm data
  *****************************************************************************
  * Copyright (C) 2001, 2003 VLC authors and VideoLAN
- * $Id: 9db6973b3b29278ca881ac6c5766b169ed3e007c $
+ * $Id: 3a653eed140c5ebb063464b60da5c7fa0bbd3bfa $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -83,6 +83,8 @@ static const uint16_t pi_channels_maps[] =
     AOUT_CHANS_4_0,   AOUT_CHANS_5_0, AOUT_CHANS_5_1,
     AOUT_CHANS_7_0,   AOUT_CHANS_7_1, AOUT_CHANS_8_1,
 };
+static_assert( ARRAY_SIZE( pi_channels_maps ) - 1 <= AOUT_CHAN_MAX,
+               "channel count mismatch" );
 
 static void S8Decode( void *, const uint8_t *, unsigned );
 static void U16BDecode( void *, const uint8_t *, unsigned );
@@ -175,6 +177,7 @@ static int DecoderOpen( vlc_object_t *p_this )
     case VLC_CODEC_S32I:
         format = VLC_CODEC_S32N;
         decode = S32IDecode;
+        /* fall through */
     case VLC_CODEC_S32N:
         bits = 32;
         break;
@@ -226,6 +229,7 @@ static int DecoderOpen( vlc_object_t *p_this )
     case VLC_CODEC_S16I:
         format = VLC_CODEC_S16N;
         decode = S16IDecode;
+        /* fall through */
     case VLC_CODEC_S16N:
         bits = 16;
         break;
@@ -237,6 +241,7 @@ static int DecoderOpen( vlc_object_t *p_this )
     case VLC_CODEC_S8:
         decode = S8Decode;
         format = VLC_CODEC_U8;
+        /* fall through */
     case VLC_CODEC_U8:
         bits = 8;
         break;
@@ -245,7 +250,7 @@ static int DecoderOpen( vlc_object_t *p_this )
     }
 
     if( p_dec->fmt_in.audio.i_channels == 0 ||
-        p_dec->fmt_in.audio.i_channels > AOUT_CHAN_MAX )
+        p_dec->fmt_in.audio.i_channels > INPUT_CHAN_MAX )
     {
         msg_Err( p_dec, "bad channels count (1-%i): %i",
                  AOUT_CHAN_MAX, p_dec->fmt_in.audio.i_channels );
@@ -268,22 +273,24 @@ static int DecoderOpen( vlc_object_t *p_this )
         return VLC_ENOMEM;
 
     /* Set output properties */
-    p_dec->fmt_out.i_cat = AUDIO_ES;
     p_dec->fmt_out.i_codec = format;
     p_dec->fmt_out.audio.i_format = format;
     p_dec->fmt_out.audio.i_rate = p_dec->fmt_in.audio.i_rate;
-    if( p_dec->fmt_in.audio.i_physical_channels )
-        p_dec->fmt_out.audio.i_physical_channels =
-                                       p_dec->fmt_in.audio.i_physical_channels;
+    if( p_dec->fmt_in.audio.i_channels <= ARRAY_SIZE( pi_channels_maps ) - 1 )
+    {
+        if( p_dec->fmt_in.audio.i_physical_channels )
+            p_dec->fmt_out.audio.i_physical_channels =
+                                           p_dec->fmt_in.audio.i_physical_channels;
+        else
+            p_dec->fmt_out.audio.i_physical_channels =
+                                  pi_channels_maps[p_dec->fmt_in.audio.i_channels];
+    }
     else
-        p_dec->fmt_out.audio.i_physical_channels =
-                              pi_channels_maps[p_dec->fmt_in.audio.i_channels];
-    if( p_dec->fmt_in.audio.i_original_channels )
-        p_dec->fmt_out.audio.i_original_channels =
-                                       p_dec->fmt_in.audio.i_original_channels;
-    else
-        p_dec->fmt_out.audio.i_original_channels =
-                                      p_dec->fmt_out.audio.i_physical_channels;
+    {
+        /* Unknown channel map, let the aout/filters decide what to do */
+        p_dec->fmt_out.audio.i_channels = p_dec->fmt_in.audio.i_channels;
+        p_dec->fmt_out.audio.i_physical_channels = 0;
+    }
     aout_FormatPrepare( &p_dec->fmt_out.audio );
 
     p_sys->decode = decode;
@@ -817,6 +824,7 @@ static int EncoderOpen( vlc_object_t *p_this )
     {
     case VLC_CODEC_S8:
         encode = S8Decode;
+        /* fall through */
     case VLC_CODEC_U8:
         p_enc->fmt_in.i_codec = VLC_CODEC_U8;
         p_enc->fmt_out.audio.i_bitspersample = 8;
@@ -833,6 +841,7 @@ static int EncoderOpen( vlc_object_t *p_this )
         break;
     case VLC_CODEC_S16I:
         encode = S16IDecode;
+        /* fall through */
     case VLC_CODEC_S16N:
         p_enc->fmt_in.i_codec = VLC_CODEC_S16N;
         p_enc->fmt_out.audio.i_bitspersample = 16;
@@ -869,6 +878,7 @@ static int EncoderOpen( vlc_object_t *p_this )
         break;
     case VLC_CODEC_S32I:
         encode = S32IEncode;
+        /* fall through */
     case VLC_CODEC_S32N:
         p_enc->fmt_in.i_codec = VLC_CODEC_S32N;
         p_enc->fmt_out.audio.i_bitspersample = 32;
@@ -879,6 +889,7 @@ static int EncoderOpen( vlc_object_t *p_this )
     case VLC_CODEC_F32B:
 #endif
         encode = F32IEncode;
+        /* fall through */
     case VLC_CODEC_FL32:
         p_enc->fmt_in.i_codec = VLC_CODEC_FL32;
         p_enc->fmt_out.audio.i_bitspersample = 32;
@@ -889,6 +900,7 @@ static int EncoderOpen( vlc_object_t *p_this )
     case VLC_CODEC_F64B:
 #endif
         encode = F64IEncode;
+        /* fall through */
     case VLC_CODEC_FL64:
         p_enc->fmt_in.i_codec = VLC_CODEC_FL64;
         p_enc->fmt_out.audio.i_bitspersample = 64;
