@@ -2,7 +2,7 @@
  * cvdsub.c : CVD Subtitle decoder
  *****************************************************************************
  * Copyright (C) 2003, 2004 VLC authors and VideoLAN
- * $Id: 313b103458bfb5cf8c0a2bdc6f8184a97eb61e47 $
+ * $Id: 4a1aeacb4c3eceb1ecc2105def3762e334e6eb13 $
  *
  * Authors: Rocky Bernstein
  *          Gildas Bazin <gbazin@videolan.org>
@@ -125,7 +125,6 @@ static int DecoderOpen( vlc_object_t *p_this )
     p_dec->pf_decode     = Decode;
     p_dec->pf_packetize  = Packetize;
 
-    p_dec->fmt_out.i_cat = SPU_ES;
     p_dec->fmt_out.i_codec = VLC_CODEC_YUVP;
 
     return VLC_SUCCESS;
@@ -140,6 +139,7 @@ static int PacketizerOpen( vlc_object_t *p_this )
 
     if( DecoderOpen( p_this ) != VLC_SUCCESS ) return VLC_EGENERIC;
 
+    p_dec->fmt_out.i_codec = VLC_CODEC_CVD;
     p_dec->p_sys->b_packetizer = true;
 
     return VLC_SUCCESS;
