@@ -4,7 +4,7 @@
  *****************************************************************************
  * Copyright (C) 2003 ANEVIA
  * Copyright (C) 2003-2009 VLC authors and VideoLAN
- * $Id: 495e5f9ac4f8e56b3bb26e8b0993828b356836e1 $
+ * $Id: 97a563e63860b556f8c636ada1af3b9ca9db340b $
  *
  * Authors: Gildas Bazin <gbazin@videolan.org>
  *          Damien LUCAS <damien.lucas@anevia.com>
@@ -367,7 +367,6 @@ static int Open( vlc_object_t *p_this )
         p_sys->i_spu_y = i_posy;
     }
 
-    p_dec->fmt_out.i_cat = SPU_ES;
     p_dec->fmt_out.i_codec = 0;
 
     default_clut_init( p_dec );
@@ -706,11 +705,8 @@ static void decode_clut( decoder_t *p_dec, bs_t *s )
     while( i_processed_length < i_segment_length )
     {
         uint8_t y, cb, cr, t;
-        uint8_t i_id;
-        uint8_t i_type;
-
-        i_id = bs_read( s, 8 );
-        i_type = bs_read( s, 3 );
+        uint_fast8_t cid = bs_read( s, 8 );
+        uint_fast8_t type = bs_read( s, 3 );
 
         bs_skip( s, 4 );
 
@@ -743,26 +739,26 @@ static void decode_clut( decoder_t *p_dec, bs_t *s )
         /* According to EN 300-743 section 7.2.3 note 1, type should
          * not have more than 1 bit set to one, but some streams don't
          * respect this note. */
-        if( ( i_type & 0x04 ) && ( i_id < 4 ) )
+        if( ( type & 0x04 ) && ( cid < 4 ) )
         {
-            p_clut->c_2b[i_id].Y = y;
-            p_clut->c_2b[i_id].Cr = cr;
-            p_clut->c_2b[i_id].Cb = cb;
-            p_clut->c_2b[i_id].T = t;
+            p_clut->c_2b[cid].Y = y;
+            p_clut->c_2b[cid].Cr = cr;
+            p_clut->c_2b[cid].Cb = cb;
+            p_clut->c_2b[cid].T = t;
         }
-        if( ( i_type & 0x02 ) && ( i_id < 16 ) )
+        if( ( type & 0x02 ) && ( cid < 16 ) )
         {
-            p_clut->c_4b[i_id].Y = y;
-            p_clut->c_4b[i_id].Cr = cr;
-            p_clut->c_4b[i_id].Cb = cb;
-            p_clut->c_4b[i_id].T = t;
+            p_clut->c_4b[cid].Y = y;
+            p_clut->c_4b[cid].Cr = cr;
+            p_clut->c_4b[cid].Cb = cb;
+            p_clut->c_4b[cid].T = t;
         }
-        if( i_type & 0x01 )
+        if( type & 0x01 )
         {
-            p_clut->c_8b[i_id].Y = y;
-            p_clut->c_8b[i_id].Cr = cr;
-            p_clut->c_8b[i_id].Cb = cb;
-            p_clut->c_8b[i_id].T = t;
+            p_clut->c_8b[cid].Y = y;
+            p_clut->c_8b[cid].Cr = cr;
+            p_clut->c_8b[cid].Cb = cb;
+            p_clut->c_8b[cid].T = t;
         }
     }
 }
