@@ -174,9 +174,6 @@ static int OpenDecoder(vlc_object_t *p_this)
     p_sys->err.error_exit = user_error_exit;
     p_sys->err.output_message = user_error_message;
 
-    /* Set output properties */
-    p_dec->fmt_out.i_cat = VIDEO_ES;
-
     /* Set callbacks */
     p_dec->pf_decode = DecodeBlock;
 
@@ -290,7 +287,8 @@ static void jpeg_GetProjection(j_decompress_ptr cinfo, video_format_t *fmt)
     {
         if (cmarker->marker == EXIF_JPEG_MARKER)
         {
-            if (!memcmp(cmarker->data, EXIF_XMP_STRING, 29))
+            if(cmarker->data_length >= 32 &&
+               !memcmp(cmarker->data, EXIF_XMP_STRING, 29))
             {
                 xmp_marker = cmarker;
                 break;
@@ -299,7 +297,7 @@ static void jpeg_GetProjection(j_decompress_ptr cinfo, video_format_t *fmt)
         cmarker = cmarker->next;
     }
 
-    if (xmp_marker == NULL || xmp_marker->data_length < 32)
+    if (xmp_marker == NULL)
         return;
     char *psz_rdf = malloc(xmp_marker->data_length - 29 + 1);
     if (unlikely(psz_rdf == NULL))
@@ -378,7 +376,8 @@ jpeg_GetOrientation( j_decompress_ptr cinfo )
 
     while ( cmarker )
     {
-        if ( cmarker->marker == EXIF_JPEG_MARKER )
+        if ( cmarker->data_length >= 32 &&
+             cmarker->marker == EXIF_JPEG_MARKER )
         {
             /* The Exif APP1 marker should contain a unique
                identification string ("Exif\0\0"). Check for it. */
@@ -394,10 +393,6 @@ jpeg_GetOrientation( j_decompress_ptr cinfo )
     if ( exif_marker == NULL )
         return 0;
 
-    /* Do we have enough data? */
-    if ( exif_marker->data_length < 32 )
-        return 0;
-
     /* Check for TIFF header and catch endianess */
     i = 0;
 
@@ -450,7 +445,7 @@ jpeg_GetOrientation( j_decompress_ptr cinfo )
 
     /* Check that we still are within the buffer and can read the tag count */
 
-    if ( ( i + 2 ) > exif_marker->data_length )
+    if ( i > exif_marker->data_length - 2 )
         return 0;
 
     /* Find out how many tags we have in IFD0. As per the TIFF spec, the first
@@ -461,7 +456,7 @@ jpeg_GetOrientation( j_decompress_ptr cinfo )
     /* Check that we still have enough data for all tags to check. The tags
        are listed in consecutive 12-byte blocks. The tag ID, type, size, and
        a pointer to the actual value, are packed into these 12 byte entries. */
-    if ( ( i + tags * 12 ) > exif_marker->data_length )
+    if ( tags * 12U > exif_marker->data_length - i )
         return 0;
 
     /* Check through IFD0 for tags of interest */
