@@ -2,7 +2,7 @@
  * SSA/ASS subtitle decoder using libass.
  *****************************************************************************
  * Copyright (C) 2008-2009 VLC authors and VideoLAN
- * $Id: de53a618ef35f144a918a56676e23c5b59ae21c3 $
+ * $Id: cbc0fd2279c74de90c4ae0b24293e975401a97f0 $
  *
  * Authors: Laurent Aimar <fenrir@videolan.org>
  *
@@ -252,7 +252,6 @@ static int Create( vlc_object_t *p_this )
     }
     ass_process_codec_private( p_track, p_dec->fmt_in.p_extra, p_dec->fmt_in.i_extra );
 
-    p_dec->fmt_out.i_cat = SPU_ES;
     p_dec->fmt_out.i_codec = VLC_CODEC_RGBA;
 
     return VLC_SUCCESS;
@@ -622,9 +621,9 @@ static int BuildRegions( rectangle_t *p_region, int i_max_region, ASS_Image *p_i
             {
                 for( int j = i+1; j < i_region; j++ )
                 {
-                    rectangle_t n = region[i];
-                    r_add( &n, &region[j] );
-                    int ds = r_surface( &n ) - r_surface( &region[i] ) - r_surface( &region[j] );
+                    rectangle_t rect = region[i];
+                    r_add( &rect, &region[j] );
+                    int ds = r_surface( &rect ) - r_surface( &region[i] ) - r_surface( &region[j] );
 
                     if( ds < i_best_ds )
                     {
