@@ -2,7 +2,7 @@
  * lpcm.c: lpcm decoder/packetizer module
  *****************************************************************************
  * Copyright (C) 1999-2008 VLC authors and VideoLAN
- * $Id: eba8ba0f923ecd01ea36a113cbb50d4e2b6c62e6 $
+ * $Id: bf9e3d6878bb9a7af7008352d31ec89c9a0448af $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *          Henri Fallon <henri@videolan.org>
@@ -259,8 +259,6 @@ static int OpenCommon( vlc_object_t *p_this, bool b_packetizer )
     p_sys->i_chans_to_reorder = 0;
 
     /* Set output properties */
-    p_dec->fmt_out.i_cat = AUDIO_ES;
-
     if( b_packetizer )
     {
         switch( i_type )
@@ -415,7 +413,6 @@ static block_t *Packetize( decoder_t *p_dec, block_t **pp_block )
     }
     p_dec->fmt_out.audio.i_rate = i_rate;
     p_dec->fmt_out.audio.i_channels = i_channels;
-    p_dec->fmt_out.audio.i_original_channels = i_original_channels;
     p_dec->fmt_out.audio.i_physical_channels = i_original_channels;
 
     if ( p_sys->i_type == LPCM_AOB )
