@@ -2,7 +2,7 @@
  * scte27.c : SCTE-27 subtitles decoder
  *****************************************************************************
  * Copyright (C) Laurent Aimar
- * $Id: bcea12551d0c41a9949217a605d6ea3a9f7e249c $
+ * $Id: dfc4d94ec36205a6781e5a38d88003427359761b $
  *
  * Authors: Laurent Aimar <fenrir _AT_ videolan _DOT_ org>
  *
@@ -503,7 +503,7 @@ static int Open(vlc_object_t *object)
     sys->segment_buffer = NULL;
 
     dec->pf_decode = Decode;
-    es_format_Init(&dec->fmt_out, SPU_ES, VLC_CODEC_YUVP);
+    dec->fmt_out.i_codec = VLC_CODEC_YUVP;
 
     return VLC_SUCCESS;
 }
