@@ -2,7 +2,7 @@
  * parse.c: SPU parser
  *****************************************************************************
  * Copyright (C) 2000-2001, 2005, 2006 VLC authors and VideoLAN
- * $Id: 9ea200ff49c38bbda3ba55448eb7005fce273203 $
+ * $Id: c4e8bc079458bdac0b2ebff0cd16139039d73110 $
  *
  * Authors: Sam Hocevar <sam@zoy.org>
  *          Laurent Aimar <fenrir@via.ecp.fr>
@@ -238,6 +238,10 @@ static int ParseControlSeq( decoder_t *p_dec, subpicture_t *p_spu,
         case SPU_CMD_FORCE_DISPLAY: /* 00 (force displaying) */
             p_spu->i_start = i_pts + date;
             p_spu->b_ephemer = true;
+            /* ignores picture date as display start time
+             * works around non displayable (offset by few ms)
+             * spu menu over still frame in SPU_Select */
+            p_spu->b_subtitle = false;
             i_index += 1;
             break;
 
@@ -260,7 +264,7 @@ static int ParseControlSeq( decoder_t *p_dec, subpicture_t *p_spu,
                 return VLC_EGENERIC;
             }
 
-            if( p_dec->fmt_in.subs.spu.palette[0] == 0xBeeF )
+            if( p_dec->fmt_in.subs.spu.palette[0] == SPU_PALETTE_DEFINED )
             {
                 unsigned int idx[4];
                 int i;
