@@ -868,7 +868,6 @@ static int OpenDecoder(vlc_object_t *p_this)
     vlc_mutex_init(&p_sys->lock);
 
     /* return our proper VLC internal state */
-    p_dec->fmt_out.i_cat = p_dec->fmt_in.i_cat;
     p_dec->fmt_out.video = p_dec->fmt_in.video;
     if (!p_dec->fmt_out.video.i_sar_num || !p_dec->fmt_out.video.i_sar_den)
     {
@@ -1258,7 +1257,11 @@ static int DecodeBlock(decoder_t *p_dec, block_t *p_block)
             return VLCDEC_SUCCESS;
     }
 
-    if (b_config_changed)
+    frame_info_t *p_info = CreateReorderInfo(p_dec, p_block);
+    if(unlikely(!p_info))
+        goto skip;
+
+    if (b_config_changed && p_info->b_flush)
     {
         /* decoding didn't start yet, which is ok for H264, let's see
          * if we can use this block to get going */
@@ -1278,13 +1281,12 @@ static int DecodeBlock(decoder_t *p_dec, block_t *p_block)
             StartVideoToolbox(p_dec);
         }
         if (!p_sys->session)
+        {
+            free(p_info);
             goto skip;
+        }
     }
 
-    frame_info_t *p_info = CreateReorderInfo(p_dec, p_block);
-    if(unlikely(!p_info))
-        goto skip;
-
     CMSampleBufferRef sampleBuffer =
         VTSampleBufferCreate(p_dec, p_sys->videoFormatDescription, p_block);
     if (unlikely(!sampleBuffer))
