@@ -2,7 +2,7 @@
  * ps.c: Program Stream demux module for VLC.
  *****************************************************************************
  * Copyright (C) 2004-2009 VLC authors and VideoLAN
- * $Id: 35cc91b7ba4049218ce38c0d23132d64e17c9768 $
+ * $Id: bf8abb75bbb84e3d1f2d35b36d5f7c9a0493b325 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -299,7 +299,7 @@ static int Probe( demux_t *p_demux, bool b_end )
     i_id = ps_pkt_id( p_pkt );
     if( i_id >= 0xc0 )
     {
-        ps_track_t *tk = &p_sys->tk[PS_ID_TO_TK(i_id)];
+        ps_track_t *tk = &p_sys->tk[ps_id_to_tk(i_id)];
         if( !ps_pkt_parse_pes( VLC_OBJECT(p_demux), p_pkt, tk->i_skip ) &&
              p_pkt->i_pts > VLC_TS_INVALID )
         {
@@ -515,7 +515,7 @@ static int Demux( demux_t *p_demux )
             }
 
             bool b_new = false;
-            ps_track_t *tk = &p_sys->tk[PS_ID_TO_TK(i_id)];
+            ps_track_t *tk = &p_sys->tk[ps_id_to_tk(i_id)];
 
             if( !tk->b_configured )
             {
@@ -529,8 +529,7 @@ static int Demux( demux_t *p_demux )
 #if 0
                         if( i_stream_id == PS_STREAM_ID_PRIVATE_STREAM1 )
                         {
-                            tk->fmt.i_codec = VLC_CODEC_ATRAC3P;
-                            tk->fmt.i_cat = AUDIO_ES;
+                            es_format_Change( &tk->fmt, AUDIO_ES, VLC_CODEC_ATRAC3P );
                             tk->fmt.audio.i_blockalign = 376;
                             tk->fmt.audio.i_channels = 2;
                             tk->fmt.audio.i_rate = 44100;
