@@ -533,7 +533,7 @@ static void SetupJ2KDescriptors( demux_t *p_demux, ts_es_t *p_es, const dvbpsi_p
     const dvbpsi_descriptor_t *p_dr = PMTEsFindDescriptor( p_dvbpsies, 0x32 );
     if( p_dr && p_dr->i_length >= 24 )
     {
-        es_format_Init( &p_es->fmt, VIDEO_ES, VLC_CODEC_JPEG2000 );
+        es_format_Change( &p_es->fmt, VIDEO_ES, VLC_CODEC_JPEG2000 );
         p_es->fmt.i_profile = p_dr->p_data[0];
         p_es->fmt.i_level = p_dr->p_data[1];
         p_es->fmt.video.i_width = GetDWBE(&p_dr->p_data[2]);
@@ -640,7 +640,7 @@ static void PMTSetupEsTeletext( demux_t *p_demux, ts_stream_t *p_pes,
     }
 
     /* */
-    es_format_Init( p_fmt, SPU_ES, VLC_CODEC_TELETEXT );
+    es_format_Change(p_fmt, SPU_ES, VLC_CODEC_TELETEXT );
 
     if( !p_demux->p_sys->b_split_es || i_page <= 0 )
     {
@@ -711,7 +711,7 @@ static void PMTSetupEsDvbSubtitle( demux_t *p_demux, ts_stream_t *p_pes,
 {
     es_format_t *p_fmt = &p_pes->p_es->fmt;
 
-    es_format_Init( p_fmt, SPU_ES, VLC_CODEC_DVBS );
+    es_format_Change( p_fmt, SPU_ES, VLC_CODEC_DVBS );
 
     dvbpsi_descriptor_t *p_dr = PMTEsFindDescriptor( p_dvbpsies, 0x59 );
     int i_page = 0;
@@ -829,7 +829,7 @@ static void OpusSetup(demux_t *demux, uint8_t *p, size_t len, es_format_t *p_fmt
         csc = p_csc[channels - 1];
         stream_count = channels - csc;
 
-        static const uint8_t map[6][7] = {
+        static const uint8_t maps[6][7] = {
             { 2,1 },
             { 1,2,3 },
             { 4,1,2,3 },
@@ -838,7 +838,7 @@ static void OpusSetup(demux_t *demux, uint8_t *p, size_t len, es_format_t *p_fmt
             { 6,1,2,3,4,5,7 },
         };
         if (channels > 2)
-            memcpy(&h.stream_map[1], map[channels-3], channels - 1);
+            memcpy(&h.stream_map[1], maps[channels-3], channels - 1);
     } else if (ccc == 0x81) {
         if (len < 4)
             goto explicit_config_too_short;
@@ -899,10 +899,13 @@ static void OpusSetup(demux_t *demux, uint8_t *p, size_t len, es_format_t *p_fmt
     h.channel_mapping = mapping;
 
     if (h.channels) {
-        opus_write_header((uint8_t**)&p_fmt->p_extra, &p_fmt->i_extra, &h, NULL /* FIXME */);
-        if (p_fmt->p_extra) {
-            p_fmt->i_cat = AUDIO_ES;
-            p_fmt->i_codec = VLC_CODEC_OPUS;
+        uint8_t *p_extra = NULL;
+        int i_extra = 0;
+        opus_write_header(&p_extra, &i_extra, &h, NULL /* FIXME */);
+        if (p_extra) {
+            es_format_Change(p_fmt, AUDIO_ES, VLC_CODEC_OPUS);
+            p_fmt->p_extra = p_extra;
+            p_fmt->i_extra = i_extra;
             p_fmt->audio.i_channels = h.channels;
             p_fmt->audio.i_rate = 48000;
         }
@@ -945,15 +948,13 @@ static void PMTSetupEs0x06( demux_t *p_demux, ts_stream_t *p_pes,
         PMTEsFindDescriptor( p_dvbpsies, 0x7a ) )
     {
         /* DVB with stream_type 0x06 (ETS EN 300 468) */
-        p_fmt->i_cat = AUDIO_ES;
-        p_fmt->i_codec = VLC_CODEC_EAC3;
+        es_format_Change( p_fmt, AUDIO_ES, VLC_CODEC_EAC3 );
     }
     else if( PMTEsHasRegistration( p_demux, p_dvbpsies, "AC-3" ) ||
              PMTEsFindDescriptor( p_dvbpsies, 0x6a ) ||
              PMTEsFindDescriptor( p_dvbpsies, 0x81 ) ) /* AC-3 channel (also in EAC3) */
     {
-        p_fmt->i_cat = AUDIO_ES;
-        p_fmt->i_codec = VLC_CODEC_A52;
+        es_format_Change( p_fmt, AUDIO_ES, VLC_CODEC_A52 );
     }
     else if( (desc = PMTEsFindDescriptor( p_dvbpsies, 0x7f ) ) &&
              desc->i_length >= 2 && desc->p_data[0] == 0x80 &&
@@ -967,21 +968,18 @@ static void PMTSetupEs0x06( demux_t *p_demux, ts_stream_t *p_pes,
              PMTEsFindDescriptor( p_dvbpsies, 0x73 ) )
     {
         /*registration descriptor(ETSI TS 101 154 Annex F)*/
-        p_fmt->i_cat = AUDIO_ES;
-        p_fmt->i_codec = VLC_CODEC_DTS;
+        es_format_Change( p_fmt, AUDIO_ES, VLC_CODEC_DTS );
     }
     else if( PMTEsHasRegistration( p_demux, p_dvbpsies, "BSSD" ) && !p_subs_dr )
     {
         /* BSSD is AES3 DATA, but could also be subtitles
          * we need to check for secondary descriptor then s*/
-        p_fmt->i_cat = AUDIO_ES;
+        es_format_Change( p_fmt, AUDIO_ES, VLC_CODEC_302M );
         p_fmt->b_packetized = true;
-        p_fmt->i_codec = VLC_CODEC_302M;
     }
     else if( PMTEsHasRegistration( p_demux, p_dvbpsies, "HEVC" ) )
     {
-        p_fmt->i_cat = VIDEO_ES;
-        p_fmt->i_codec = VLC_CODEC_HEVC;
+        es_format_Change( p_fmt, VIDEO_ES, VLC_CODEC_HEVC );
     }
     else if ( p_demux->p_sys->standard == TS_STANDARD_ARIB )
     {
@@ -995,14 +993,14 @@ static void PMTSetupEs0x06( demux_t *p_demux, ts_stream_t *p_pes,
             if( i_data_component_id == 0x0008 &&
                 PMTEsHasComponentTagBetween( p_dvbpsies, 0x30, 0x37 ) )
             {
-                es_format_Init( p_fmt, SPU_ES, VLC_CODEC_ARIB_A );
+                es_format_Change( p_fmt, SPU_ES, VLC_CODEC_ARIB_A );
                 p_fmt->psz_language = strndup ( "jpn", 3 );
                 p_fmt->psz_description = strdup( _("ARIB subtitles") );
             }
             else if( i_data_component_id == 0x0012 &&
                      PMTEsHasComponentTagBetween( p_dvbpsies, 0x87, 0x88 ) )
             {
-                es_format_Init( p_fmt, SPU_ES, VLC_CODEC_ARIB_C );
+                es_format_Change( p_fmt, SPU_ES, VLC_CODEC_ARIB_C );
                 p_fmt->psz_language = strndup ( "jpn", 3 );
                 p_fmt->psz_description = strdup( _("ARIB subtitles") );
             }
@@ -1076,11 +1074,8 @@ static void PMTSetupEs0xEA( demux_t *p_demux, ts_es_t *p_es,
         return;
     }
 
-    es_format_t *p_fmt = &p_es->fmt;
-
     /* registration descriptor for VC-1 (SMPTE rp227) */
-    p_fmt->i_cat = VIDEO_ES;
-    p_fmt->i_codec = VLC_CODEC_VC1;
+    es_format_Change( &p_es->fmt, VIDEO_ES, VLC_CODEC_VC1 );
 
     /* XXX With Simple and Main profile the SEQUENCE
      * header is modified: video width and height are
@@ -1098,12 +1093,9 @@ static void PMTSetupEs0xD1( demux_t *p_demux, ts_es_t *p_es,
         return;
     }
 
-    es_format_t *p_fmt = &p_es->fmt;
-
     /* registration descriptor for Dirac
      * (backwards compatable with VC-2 (SMPTE Sxxxx:2008)) */
-    p_fmt->i_cat = VIDEO_ES;
-    p_fmt->i_codec = VLC_CODEC_DIRAC;
+    es_format_Change( &p_es->fmt, VIDEO_ES, VLC_CODEC_DIRAC );
 }
 
 static void PMTSetupEs0xA0( demux_t *p_demux, ts_es_t *p_es,
@@ -1119,9 +1111,9 @@ static void PMTSetupEs0xA0( demux_t *p_demux, ts_es_t *p_es,
     }
 
     es_format_t *p_fmt = &p_es->fmt;
-    p_fmt->i_cat = VIDEO_ES;
-    p_fmt->i_codec = VLC_FOURCC( p_dr->p_data[0], p_dr->p_data[1],
-                                 p_dr->p_data[2], p_dr->p_data[3] );
+    es_format_Change( &p_es->fmt, VIDEO_ES,
+                      VLC_FOURCC( p_dr->p_data[0], p_dr->p_data[1],
+                                 p_dr->p_data[2], p_dr->p_data[3] ) );
     p_fmt->video.i_width = GetWBE( &p_dr->p_data[4] );
     p_fmt->video.i_height = GetWBE( &p_dr->p_data[6] );
     p_fmt->video.i_visible_width = p_fmt->video.i_width;
@@ -1152,10 +1144,10 @@ static void PMTSetupEs0x83( const dvbpsi_pmt_t *p_pmt, ts_es_t *p_es, int i_pid
         ( i_pid >> 8 ) == 0x11 )
     {
         /* Not enough ? might contain 0x83 private descriptor, 2 bytes 0x473F */
-        es_format_Init( &p_es->fmt, AUDIO_ES, VLC_CODEC_WIDI_LPCM );
+        es_format_Change( &p_es->fmt, AUDIO_ES, VLC_CODEC_WIDI_LPCM );
     }
     else
-        es_format_Init( &p_es->fmt, AUDIO_ES, VLC_CODEC_DVD_LPCM );
+        es_format_Change( &p_es->fmt, AUDIO_ES, VLC_CODEC_DVD_LPCM );
 }
 
 static bool PMTSetupEsHDMV( demux_t *p_demux, ts_es_t *p_es,
@@ -1167,44 +1159,36 @@ static bool PMTSetupEsHDMV( demux_t *p_demux, ts_es_t *p_es,
     switch( p_dvbpsies->i_type )
     {
     case 0x80:
-        p_fmt->i_cat = AUDIO_ES;
-        p_fmt->i_codec = VLC_CODEC_BD_LPCM;
+        es_format_Change( p_fmt, AUDIO_ES, VLC_CODEC_BD_LPCM );
         break;
     case 0x81:
-        p_fmt->i_cat = AUDIO_ES;
-        p_fmt->i_codec = VLC_CODEC_A52;
+        es_format_Change( p_fmt, AUDIO_ES, VLC_CODEC_A52 );
         break;
     case 0x82:
     case 0x85: /* DTS-HD High resolution audio */
     case 0x86: /* DTS-HD Master audio */
     case 0xA2: /* Secondary DTS audio */
-        p_fmt->i_cat = AUDIO_ES;
-        p_fmt->i_codec = VLC_CODEC_DTS;
+        es_format_Change( p_fmt, AUDIO_ES, VLC_CODEC_DTS );
         break;
 
     case 0x83: /* TrueHD AC3 */
-        p_fmt->i_cat = AUDIO_ES;
-        p_fmt->i_codec = VLC_CODEC_TRUEHD;
+        es_format_Change( p_fmt, AUDIO_ES, VLC_CODEC_TRUEHD );
         break;
 
     case 0x84: /* E-AC3 */
     case 0xA1: /* Secondary E-AC3 */
-        p_fmt->i_cat = AUDIO_ES;
-        p_fmt->i_codec = VLC_CODEC_EAC3;
+        es_format_Change( p_fmt, AUDIO_ES, VLC_CODEC_EAC3 );
         break;
     case 0x90: /* Presentation graphics */
-        p_fmt->i_cat = SPU_ES;
-        p_fmt->i_codec = VLC_CODEC_BD_PG;
+        es_format_Change( p_fmt, SPU_ES, VLC_CODEC_BD_PG );
         break;
     case 0x91: /* Interactive graphics */
         return false;
     case 0x92: /* Subtitle */
-        p_fmt->i_cat = SPU_ES;
-        p_fmt->i_codec = VLC_CODEC_BD_TEXT;
+        es_format_Change( p_fmt, SPU_ES, VLC_CODEC_BD_TEXT );
         break;
     case 0xEA:
-        p_fmt->i_cat = VIDEO_ES;
-        p_fmt->i_codec = VLC_CODEC_VC1;
+        es_format_Change( p_fmt, VIDEO_ES, VLC_CODEC_VC1 );
         break;
     default:
         msg_Info( p_demux, "HDMV registration not implemented for pid 0x%x type 0x%x",
@@ -1219,9 +1203,9 @@ static bool PMTSetupEsRegistration( demux_t *p_demux, ts_es_t *p_es,
 {
     static const struct
     {
-        char         psz_tag[5];
-        int          i_cat;
-        vlc_fourcc_t i_codec;
+        char                      psz_tag[5];
+        enum es_format_category_e i_cat;
+        vlc_fourcc_t              i_codec;
     } p_regs[] = {
         { "AC-3", AUDIO_ES, VLC_CODEC_A52   },
         { "EAC3", AUDIO_ES, VLC_CODEC_EAC3  },
@@ -1239,8 +1223,7 @@ static bool PMTSetupEsRegistration( demux_t *p_demux, ts_es_t *p_es,
     {
         if( PMTEsHasRegistration( p_demux, p_dvbpsies, p_regs[i].psz_tag ) )
         {
-            p_fmt->i_cat   = p_regs[i].i_cat;
-            p_fmt->i_codec = p_regs[i].i_codec;
+            es_format_Change( p_fmt, p_regs[i].i_cat, p_regs[i].i_codec );
 
             /* System A AC3 extension, see ATSC A/52 Annex G.2 */
             if ( p_regs[i].i_codec == VLC_CODEC_A52 && p_dvbpsies->i_type == 0x87 )
@@ -1323,88 +1306,85 @@ static void PIDFillFormat( demux_t *p_demux, ts_stream_t *p_pes,
     switch( i_stream_type )
     {
     case 0x01:  /* MPEG-1 video */
-        es_format_Init( fmt, VIDEO_ES, VLC_CODEC_MPGV );
+        es_format_Change( fmt, VIDEO_ES, VLC_CODEC_MPGV );
         fmt->i_original_fourcc = VLC_CODEC_MP1V;
         break;
     case 0x02:  /* MPEG-2 video */
     case 0x80:  /* MPEG-2 MOTO video */
-        es_format_Init( fmt, VIDEO_ES, VLC_CODEC_MPGV );
+        es_format_Change( fmt, VIDEO_ES, VLC_CODEC_MPGV );
         break;
     case 0x03:  /* MPEG-1 audio */
     case 0x04:  /* MPEG-2 audio */
-        es_format_Init( fmt, AUDIO_ES, VLC_CODEC_MPGA );
+        es_format_Change( fmt, AUDIO_ES, VLC_CODEC_MPGA );
         break;
     case 0x0f:  /* ISO/IEC 13818-7 Audio with ADTS transport syntax */
-        es_format_Init( fmt, AUDIO_ES, VLC_CODEC_MP4A );
+        es_format_Change( fmt, AUDIO_ES, VLC_CODEC_MP4A );
         fmt->i_original_fourcc = VLC_FOURCC('A','D','T','S');
         break;
     case 0x10:  /* MPEG4 (video) */
-        es_format_Init( fmt, VIDEO_ES, VLC_CODEC_MP4V );
+        es_format_Change( fmt, VIDEO_ES, VLC_CODEC_MP4V );
         break;
     case 0x11:  /* MPEG4 (audio) LATM */
-        es_format_Init( fmt, AUDIO_ES, VLC_CODEC_MP4A );
+        es_format_Change( fmt, AUDIO_ES, VLC_CODEC_MP4A );
         fmt->i_original_fourcc = VLC_FOURCC('L','A','T','M');
         break;
     case 0x1B:  /* H264 <- check transport syntax/needed descriptor */
-        es_format_Init( fmt, VIDEO_ES, VLC_CODEC_H264 );
+        es_format_Change( fmt, VIDEO_ES, VLC_CODEC_H264 );
         break;
     case 0x1C:  /* ISO/IEC 14496-3 Audio, without using any additional
                    transport syntax, such as DST, ALS and SLS */
-        es_format_Init( fmt, AUDIO_ES, VLC_CODEC_MP4A );
+        es_format_Change( fmt, AUDIO_ES, VLC_CODEC_MP4A );
         break;
     case 0x24:  /* HEVC */
-        es_format_Init( fmt, VIDEO_ES, VLC_CODEC_HEVC );
+        es_format_Change( fmt, VIDEO_ES, VLC_CODEC_HEVC );
         break;
     case 0x42:  /* CAVS (Chinese AVS) */
-        es_format_Init( fmt, VIDEO_ES, VLC_CODEC_CAVS );
+        es_format_Change( fmt, VIDEO_ES, VLC_CODEC_CAVS );
         break;
 
     case 0x81:  /* A52 (audio) */
-        es_format_Init( fmt, AUDIO_ES, VLC_CODEC_A52 );
+        es_format_Change( fmt, AUDIO_ES, VLC_CODEC_A52 );
         break;
     case 0x82:  /* SCTE-27 (sub) */
-        es_format_Init( fmt, SPU_ES, VLC_CODEC_SCTE_27 );
+        es_format_Change( fmt, SPU_ES, VLC_CODEC_SCTE_27 );
         *p_datatype = TS_TRANSPORT_SECTIONS;
         ts_sections_processor_Add( p_demux, &p_pes->p_sections_proc, 0xC6, 0x00,
                                    SCTE27_Section_Callback, p_pes );
         break;
     case 0x84:  /* SDDS (audio) */
-        es_format_Init( fmt, AUDIO_ES, VLC_CODEC_SDDS );
+        es_format_Change( fmt, AUDIO_ES, VLC_CODEC_SDDS );
         break;
     case 0x85:  /* DTS (audio) FIXME: HDMV Only ? */
-        es_format_Init( fmt, AUDIO_ES, VLC_CODEC_DTS );
+        es_format_Change( fmt, AUDIO_ES, VLC_CODEC_DTS );
         break;
     case 0x87: /* E-AC3, ATSC */
-        es_format_Init( fmt, AUDIO_ES, VLC_CODEC_EAC3 );
+        es_format_Change( fmt, AUDIO_ES, VLC_CODEC_EAC3 );
         break;
     case 0x8a: /* DTS (audio) */
-        es_format_Init( fmt, AUDIO_ES, VLC_CODEC_DTS );
+        es_format_Change( fmt, AUDIO_ES, VLC_CODEC_DTS );
         break;
     case 0x91:  /* A52 vls (audio) */
-        es_format_Init( fmt, AUDIO_ES, VLC_FOURCC( 'a', '5', '2', 'b' ) );
+        es_format_Change( fmt, AUDIO_ES, VLC_FOURCC( 'a', '5', '2', 'b' ) );
         break;
     case 0x92:  /* DVD_SPU vls (sub) */
-        es_format_Init( fmt, SPU_ES, VLC_FOURCC( 's', 'p', 'u', 'b' ) );
+        es_format_Change( fmt, SPU_ES, VLC_FOURCC( 's', 'p', 'u', 'b' ) );
         break;
 
     case 0x94:  /* SDDS (audio) */
-        es_format_Init( fmt, AUDIO_ES, VLC_FOURCC( 's', 'd', 'd', 'b' ) );
+        es_format_Change( fmt, AUDIO_ES, VLC_FOURCC( 's', 'd', 'd', 'b' ) );
         break;
 
     case 0xa0:  /* MSCODEC vlc (video) (fixed later) */
-        es_format_Init( fmt, UNKNOWN_ES, 0 );
+        es_format_Change( fmt, UNKNOWN_ES, 0 );
         break;
 
     case 0x06:  /* PES_PRIVATE  (fixed later) */
     case 0x12:  /* MPEG-4 generic (sub/scene/...) (fixed later) */
     case 0xEA:  /* Privately managed ES (VC-1) (fixed later */
     default:
-        es_format_Init( fmt, UNKNOWN_ES, 0 );
+        es_format_Change( fmt, UNKNOWN_ES, 0 );
         break;
     }
-
-    /* PES packets usually contain truncated frames */
-    fmt->b_packetized = false;
 }
 
 static void FillPESFromDvbpsiES( demux_t *p_demux,
@@ -1505,6 +1485,9 @@ static void FillPESFromDvbpsiES( demux_t *p_demux,
         SetupAudioExtendedDescriptors( p_demux, p_pes->p_es, p_dvbpsies );
     }
 
+    /* PES packets usually contain truncated frames */
+    p_pes->p_es->fmt.b_packetized = false;
+
     /* Set Groups / ID */
     p_pes->p_es->fmt.i_group = p_dvbpsipmt->i_program_number;
     if( p_demux->p_sys->b_es_id_pid )
@@ -1836,8 +1819,7 @@ static void PMTCallBack( void *data, dvbpsi_pmt_t *p_dvbpsipmt )
                     ts_es_t *p_eas_es = ts_es_New( p_pmt );
                     if( likely(p_eas_es) )
                     {
-                        p_eas_es->fmt.i_codec = VLC_CODEC_SCTE_18;
-                        p_eas_es->fmt.i_cat = SPU_ES;
+                        es_format_Change( &p_eas_es->fmt, SPU_ES, VLC_CODEC_SCTE_18 );
                         p_eas_es->fmt.i_id = ATSC_BASE_PID;
                         p_eas_es->fmt.i_group = p_pmt->i_number;
                         p_eas_es->fmt.psz_description = strdup(SCTE18_DESCRIPTION);
@@ -1919,14 +1901,13 @@ int UserPmt( demux_t *p_demux, const char *psz_fmt )
     demux_sys_t *p_sys = p_demux->p_sys;
     char *psz_dup = strdup( psz_fmt );
     char *psz = psz_dup;
-    int  i_pid;
     int  i_number;
 
     if( !psz_dup )
         return VLC_ENOMEM;
 
     /* Parse PID */
-    i_pid = strtol( psz, &psz, 0 );
+    unsigned long i_pid = strtoul( psz, &psz, 0 );
     if( i_pid < 2 || i_pid >= 8192 )
         goto error;
 
@@ -1938,7 +1919,7 @@ int UserPmt( demux_t *p_demux, const char *psz_fmt )
     /* */
     ts_pid_t *pmtpid = GetPID(p_sys, i_pid);
 
-    msg_Dbg( p_demux, "user pmt specified (pid=%d,number=%d)", i_pid, i_number );
+    msg_Dbg( p_demux, "user pmt specified (pid=%lu,number=%d)", i_pid, i_number );
     if ( !PIDSetup( p_demux, TYPE_PMT, pmtpid, GetPID(p_sys, 0) ) )
         goto error;
 
@@ -1961,12 +1942,11 @@ int UserPmt( demux_t *p_demux, const char *psz_fmt )
     while( psz && *psz )
     {
         char *psz_next = strchr( psz, ',' );
-        int i_pid;
 
         if( psz_next )
             *psz_next++ = '\0';
 
-        i_pid = strtol( psz, &psz, 0 );
+        i_pid = strtoul( psz, &psz, 0 );
         if( *psz != ':' || i_pid < 2 || i_pid >= 8192 )
             goto next;
 
@@ -2006,7 +1986,7 @@ int UserPmt( demux_t *p_demux, const char *psz_fmt )
                 else if( !strcmp( psz_opt, "spu" ) )
                     i_cat = SPU_ES;
 
-                es_format_Init( fmt, i_cat, i_codec );
+                es_format_Change( fmt, i_cat, i_codec );
                 fmt->b_packetized = false;
             }
             else
@@ -2021,7 +2001,7 @@ int UserPmt( demux_t *p_demux, const char *psz_fmt )
 
             if( fmt->i_cat != UNKNOWN_ES )
             {
-                msg_Dbg( p_demux, "  * es pid=%d fcc=%4.4s", i_pid,
+                msg_Dbg( p_demux, "  * es pid=%lu fcc=%4.4s", i_pid,
                          (char*)&fmt->i_codec );
                 pid->u.p_stream->p_es->id = es_out_Add( p_demux->out, fmt );
                 p_sys->i_pmt_es++;
