@@ -2,7 +2,7 @@
  * nsv.c: NullSoft Video demuxer.
  *****************************************************************************
  * Copyright (C) 2004-2007 VLC authors and VideoLAN
- * $Id: 40f9eb7ea0062a7d540fd5f4443e82c4e60a7617 $
+ * $Id: a30667da6529e9a4a233f525c35efcd2465c2ec6 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -238,7 +238,8 @@ static int Demux( demux_t *p_demux )
                     p_sys->p_sub = es_out_Add( p_demux->out, &p_sys->fmt_sub );
                     es_out_Control( p_demux->out, ES_OUT_SET_ES, p_sys->p_sub );
                 }
-                vlc_stream_Read( p_demux->s, NULL, 2 );
+                if( vlc_stream_Read( p_demux->s, NULL, 2 ) < 2 )
+                    return 0;
 
                 if( ( p_frame = vlc_stream_Block( p_demux->s, i_aux - 2 ) ) )
                 {
@@ -297,7 +298,8 @@ static int Demux( demux_t *p_demux )
         if( p_sys->fmt_audio.i_codec == VLC_FOURCC( 'a', 'r', 'a', 'w' ) )
         {
             uint8_t h[4];
-            vlc_stream_Read( p_demux->s, h, 4 );
+            if( vlc_stream_Read( p_demux->s, h, 4 ) < 4 )
+                return 0;
 
             p_sys->fmt_audio.audio.i_channels = h[1];
             p_sys->fmt_audio.audio.i_rate = GetWLE( &h[2] );
@@ -439,10 +441,9 @@ static int ReSynch( demux_t *p_demux )
             if( !memcmp( p_peek, "NSVf", 4 )
              || !memcmp( p_peek, "NSVs", 4 ) )
             {
-                if( i_skip > 0 )
-                {
-                    vlc_stream_Read( p_demux->s, NULL, i_skip );
-                }
+                if( i_skip > 0
+                 && vlc_stream_Read( p_demux->s, NULL, i_skip ) )
+                    return VLC_EGENERIC;
                 return VLC_SUCCESS;
             }
             p_peek++;
