@@ -2,7 +2,7 @@
  * itml.c : iTunes Music Library import functions
  *******************************************************************************
  * Copyright (C) 2007 VLC authors and VideoLAN
- * $Id: 47c813a9bdd08f8c81317a0c12a9e21769e08427 $
+ * $Id: bd1b1bebe4e6384fef6bdc31d244b631d6654917 $
  *
  * Authors: Yoann Peronneau <yoann@videolan.org>
  *
@@ -30,64 +30,53 @@
 #endif
 
 #include <vlc_common.h>
-#include <vlc_demux.h>
+#include <vlc_access.h>
 #include <vlc_xml.h>
 #include <vlc_strings.h>
 #include <vlc_url.h>
-#include <vlc_fixups.h>
 
 #include "itml.h"
 #include "playlist.h"
 
-struct demux_sys_t
-{
-    int i_ntracks;
-};
-
-static int Demux( demux_t * );
+static int ReadDir( stream_t *, input_item_node_t * );
 
 /**
  * \brief iTML submodule initialization function
  */
 int Import_iTML( vlc_object_t *p_this )
 {
-    demux_t *p_demux = (demux_t *)p_this;
-    CHECK_FILE();
-    if( !demux_IsPathExtension( p_demux, ".xml" )
-     && !demux_IsForced( p_demux, "itml" ) )
-        return VLC_EGENERIC; \
-    STANDARD_DEMUX_INIT_MSG( "using iTunes Media Library reader" );
+    stream_t *p_demux = (stream_t *)p_this;
+    CHECK_FILE(p_demux);
+    if( !stream_HasExtension( p_demux, ".xml" )
+     && !p_demux->obj.force )
+        return VLC_EGENERIC;
 
     const uint8_t *p_peek;
-    const ssize_t i_peek = vlc_stream_Peek( p_demux->s, &p_peek, 128 );
+    const ssize_t i_peek = vlc_stream_Peek( p_demux->p_source, &p_peek, 128 );
     if ( i_peek < 32 ||
          !strnstr( (const char *) p_peek, "<!DOCTYPE plist ", i_peek ) )
-    {
-        Close_iTML( p_this );
         return VLC_EGENERIC;
-    }
-    return VLC_SUCCESS;
-}
 
-void Close_iTML( vlc_object_t *p_this )
-{
-    demux_t *p_demux = (demux_t *)p_this;
-    free( p_demux->p_sys );
+    msg_Dbg( p_demux, "using iTunes Media Library reader" );
+
+    p_demux->pf_readdir = ReadDir;
+    p_demux->pf_control = access_vaDirectoryControlHelper;
+
+    return VLC_SUCCESS;
 }
 
 /**
  * \brief demuxer function for iTML parsing
  */
-int Demux( demux_t *p_demux )
+static int ReadDir( stream_t *p_demux, input_item_node_t *p_subitems )
 {
     xml_reader_t *p_xml_reader;
     const char *node;
 
-    input_item_t *p_current_input = GetCurrentItem(p_demux);
-    p_demux->p_sys->i_ntracks = 0;
+    p_demux->p_sys = (void *)(uintptr_t)0;
 
     /* create new xml parser from stream */
-    p_xml_reader = xml_ReaderCreate( p_demux, p_demux->s );
+    p_xml_reader = xml_ReaderCreate( p_demux, p_demux->p_source );
     if( !p_xml_reader )
         goto end;
 
@@ -111,12 +100,10 @@ int Demux( demux_t *p_demux )
         goto end;
     }
 
-    input_item_node_t *p_subitems = input_item_node_Create( p_current_input );
     xml_elem_hnd_t pl_elements[] =
         { {"dict",    COMPLEX_CONTENT, {.cmplx = parse_plist_dict} } };
     parse_plist_node( p_demux, p_subitems, NULL, p_xml_reader, "plist",
                       pl_elements );
-    input_item_node_PostAndDelete( p_subitems );
 
 end:
     if( p_xml_reader )
@@ -129,7 +116,7 @@ end:
 /**
  * \brief parse the root node of the playlist
  */
-static bool parse_plist_node( demux_t *p_demux, input_item_node_t *p_input_node,
+static bool parse_plist_node( stream_t *p_demux, input_item_node_t *p_input_node,
                               track_elem_t *p_track, xml_reader_t *p_xml_reader,
                               const char *psz_element,
                               xml_elem_hnd_t *p_handlers )
@@ -165,7 +152,7 @@ static bool parse_plist_node( demux_t *p_demux, input_item_node_t *p_input_node,
  * \brief parse a <dict>
  * \param COMPLEX_INTERFACE
  */
-static bool parse_dict( demux_t *p_demux, input_item_node_t *p_input_node,
+static bool parse_dict( stream_t *p_demux, input_item_node_t *p_input_node,
                         track_elem_t *p_track, xml_reader_t *p_xml_reader,
                         const char *psz_element, xml_elem_hnd_t *p_handlers )
 {
@@ -255,7 +242,7 @@ end:
     return b_ret;
 }
 
-static bool parse_plist_dict( demux_t *p_demux, input_item_node_t *p_input_node,
+static bool parse_plist_dict( stream_t *p_demux, input_item_node_t *p_input_node,
                               track_elem_t *p_track, xml_reader_t *p_xml_reader,
                               const char *psz_element,
                               xml_elem_hnd_t *p_handlers )
@@ -277,7 +264,7 @@ static bool parse_plist_dict( demux_t *p_demux, input_item_node_t *p_input_node,
                        "dict", pl_elements );
 }
 
-static bool parse_tracks_dict( demux_t *p_demux, input_item_node_t *p_input_node,
+static bool parse_tracks_dict( stream_t *p_demux, input_item_node_t *p_input_node,
                                track_elem_t *p_track, xml_reader_t *p_xml_reader,
                                const char *psz_element,
                                xml_elem_hnd_t *p_handlers )
@@ -292,13 +279,13 @@ static bool parse_tracks_dict( demux_t *p_demux, input_item_node_t *p_input_node
     parse_dict( p_demux, p_input_node, NULL, p_xml_reader,
                 "dict", tracks_elements );
 
-    msg_Info( p_demux, "added %i tracks successfully",
-              p_demux->p_sys->i_ntracks );
+    msg_Info( p_demux, "added %zi tracks successfully",
+              (size_t)p_demux->p_sys );
 
     return true;
 }
 
-static bool parse_track_dict( demux_t *p_demux, input_item_node_t *p_input_node,
+static bool parse_track_dict( stream_t *p_demux, input_item_node_t *p_input_node,
                               track_elem_t *p_track, xml_reader_t *p_xml_reader,
                               const char *psz_element,
                               xml_elem_hnd_t *p_handlers )
@@ -340,7 +327,7 @@ static bool parse_track_dict( demux_t *p_demux, input_item_node_t *p_input_node,
     add_meta( p_new_input, p_track );
     input_item_Release( p_new_input );
 
-    p_demux->p_sys->i_ntracks++;
+    p_demux->p_sys = (void *)((uintptr_t)p_demux->p_sys + 1);
 
     free_track( p_track );
     return i_ret;
@@ -428,7 +415,7 @@ static bool add_meta( input_item_t *p_input_item, track_elem_t *p_track )
 /**
  * \brief skips complex element content that we can't manage
  */
-static bool skip_element( demux_t *p_demux, input_item_node_t *p_input_node,
+static bool skip_element( stream_t *p_demux, input_item_node_t *p_input_node,
                           track_elem_t *p_track, xml_reader_t *p_xml_reader,
                           const char *psz_element, xml_elem_hnd_t *p_handlers )
 {
