@@ -2,7 +2,7 @@
  * wav.c : wav file input module for vlc
  *****************************************************************************
  * Copyright (C) 2001-2008 VLC authors and VideoLAN
- * $Id: db7a32c93cadc388f0d9fab606deb85558432368 $
+ * $Id: f49003990817c44392506b5a400ce9df5c2764ff $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -29,6 +29,8 @@
 # include "config.h"
 #endif
 
+#include <assert.h>
+
 #include <vlc_common.h>
 #include <vlc_plugin.h>
 #include <vlc_demux.h>
@@ -37,6 +39,9 @@
 
 #include "windows_audio_commons.h"
 
+#define WAV_CHAN_MAX 32
+static_assert( INPUT_CHAN_MAX >= WAV_CHAN_MAX, "channel count mismatch" );
+
 /*****************************************************************************
  * Module descriptor
  *****************************************************************************/
@@ -271,7 +276,8 @@ static int Open( vlc_object_t * p_this )
             }
         }
     }
-    if( p_sys->i_channel_mask == 0 && p_sys->fmt.audio.i_channels > 2 )
+    if( p_sys->i_channel_mask == 0 && p_sys->fmt.audio.i_channels > 2
+     && p_sys->fmt.audio.i_channels <= AOUT_CHAN_MAX )
     {
         /* A dwChannelMask of 0 tells the audio device to render the first
          * channel to the first port on the device, the second channel to the
@@ -304,8 +310,7 @@ static int Open( vlc_object_t * p_this )
                  p_sys->i_channel_mask, p_sys->i_chans_to_reorder );
     }
 
-    p_sys->fmt.audio.i_physical_channels =
-    p_sys->fmt.audio.i_original_channels = p_sys->i_channel_mask;
+    p_sys->fmt.audio.i_physical_channels = p_sys->i_channel_mask;
 
     if( p_sys->fmt.i_extra > 0 )
     {
@@ -555,7 +560,7 @@ static int FrameInfo_PCM( unsigned int *pi_size, int *pi_samples,
 
     if( p_fmt->audio.i_rate > 352800
      || p_fmt->audio.i_bitspersample > 64
-     || p_fmt->audio.i_channels > AOUT_CHAN_MAX )
+     || p_fmt->audio.i_channels > WAV_CHAN_MAX )
         return VLC_EGENERIC;
 
     /* read samples for 50ms of */
