@@ -2,7 +2,7 @@
  * CompatibilityFixes.h: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2011-2017 VLC authors and VideoLAN
- * $Id: 0a0a51cb7b1d390c1e9fe6e8df50e1d8ca8ca81d $
+ * $Id: 1f62d71187e23cd87a7c1ff5cba850993804d509 $
  *
  * Authors: Felix Paul Kühne <fkuehne -at- videolan -dot- org>
  *          Marvin Scholz <epirat07 -at- gmail -dot- com>
@@ -54,5 +54,5 @@ typedef NSUInteger NSWindowStyleMask;
 
 #endif
 
-void swapoutOverride(Class cls, SEL selector);
+void swapoutOverride(Class _Nonnull cls, SEL _Nonnull selector);
 
