@@ -2,7 +2,7 @@
  * VLCControlsBarCommon.h: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2012-2016 VLC authors and VideoLAN
- * $Id: 18a55f1778b66745fc0bb47a1bbe4b54aa19c52e $
+ * $Id: eac80f6df2c384e464c85374e970df7f2440448e $
  *
  * Authors: Felix Paul Kühne <fkuehne -at- videolan -dot- org>
  *          David Fuhrmann <david dot fuhrmann at googlemail dot com>
@@ -26,6 +26,7 @@
 #import "misc.h"
 
 #import "VLCTimeField.h"
+#import "VLCSlider.h"
 
 /*****************************************************************************
  * VLCControlsBarCommon
@@ -42,11 +43,7 @@
 @property (readwrite, strong) IBOutlet NSButton *backwardButton;
 @property (readwrite, strong) IBOutlet NSButton *forwardButton;
 
-@property (readwrite, strong) IBOutlet VLCProgressView *progressView;
-@property (readwrite, strong) IBOutlet TimeLineSlider *timeSlider;
-@property (readwrite, strong) IBOutlet VLCThreePartImageView *timeSliderGradientView;
-@property (readwrite, strong) IBOutlet VLCThreePartImageView *timeSliderBackgroundView;
-@property (readwrite, strong) IBOutlet NSProgressIndicator *progressBar;
+@property (readwrite, strong) IBOutlet VLCSlider *timeSlider;
 
 @property (readwrite, strong) IBOutlet VLCTimeField *timeField;
 @property (readwrite, strong) IBOutlet NSButton *fullscreenButton;
@@ -67,7 +64,6 @@
 - (IBAction)fullscreen:(id)sender;
 
 - (void)updateTimeSlider;
-- (void)drawFancyGradientEffectForTimeSlider;
 - (void)updateControls;
 - (void)setPause;
 - (void)setPlay;
