@@ -2,7 +2,7 @@
  * VLCConvertAndSaveWindowController.m: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2012 Felix Paul Kühne
- * $Id: 8d0fed16bdbeb3f18952c189aea1d8a421489863 $
+ * $Id: 55000072b787a6ef86da64c430bd2809d49e124d $
  *
  * Authors: Felix Paul Kühne <fkuehne -at- videolan -dot- org>
  *
@@ -287,14 +287,13 @@
         input_item_AddOption(p_input, [[NSString stringWithFormat:@"ttl=%@", [_streamTTLField stringValue]] UTF8String], VLC_INPUT_OPTION_TRUSTED);
 
     int returnValue;
-    returnValue = playlist_AddInput(p_playlist, p_input, PLAYLIST_STOP, true );
+    returnValue = playlist_AddInput(p_playlist, p_input, false, true );
 
     if (returnValue == VLC_SUCCESS) {
         /* let's "play" */
         PL_LOCK;
         playlist_item_t *p_item = playlist_ItemGetByInput(p_playlist, p_input);
-        playlist_Control(p_playlist, PLAYLIST_VIEWPLAY, pl_Locked, NULL,
-                         p_item);
+        playlist_ViewPlay(p_playlist, NULL, p_item);
         PL_UNLOCK;
     }
     else
