@@ -2,7 +2,7 @@
  * VLCFSPanelController.m: macOS fullscreen controls window controller
  *****************************************************************************
  * Copyright (C) 2006-2016 VLC authors and VideoLAN
- * $Id: 4400a113eb8d8ac84b1fe1cd7cb1d71b2f30c1ef $
+ * $Id: 5ea384221817071a1777172ecc5ef9dda07659c1 $
  *
  * Authors: Jérôme Decoodt <djc at videolan dot org>
  *          Felix Paul Kühne <fkuehne at videolan dot org>
@@ -82,7 +82,7 @@ static NSString *kAssociatedFullscreenRect = @"VLCFullscreenAssociatedWindowRect
 
 #ifdef MAC_OS_X_VERSION_10_10
     /* Inject correct background view depending on OS support */
-    if (OSX_YOSEMITE_OR_HIGHER) {
+    if (OSX_YOSEMITE_AND_HIGHER) {
         [self injectVisualEffectView];
     } else {
         [self injectBackgroundView];
