@@ -2,7 +2,7 @@
  * ControlsBar.h: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2012-2016 VLC authors and VideoLAN
- * $Id: a9e66acc514a248426f41d5374ad28df011f50db $
+ * $Id: 5010c50e7ba4aa2512a0432089b3c0b22b4cff0d $
  *
  * Authors: Felix Paul Kühne <fkuehne -at- videolan -dot- org>
  *          David Fuhrmann <david dot fuhrmann at googlemail dot com>
@@ -37,11 +37,16 @@
 @property (readwrite, strong) IBOutlet NSButton *stopButton;
 
 @property (readwrite, strong) IBOutlet NSButton *prevButton;
+@property (readwrite, strong) IBOutlet NSLayoutConstraint *prevButtonWidthConstraint;
 @property (readwrite, strong) IBOutlet NSButton *nextButton;
+@property (readwrite, strong) IBOutlet NSLayoutConstraint *nextButtonWidthConstraint;
 
 @property (readwrite, strong) IBOutlet NSButton *playlistButton;
 @property (readwrite, strong) IBOutlet NSButton *repeatButton;
+@property (readwrite, strong) IBOutlet NSLayoutConstraint *repeatButtonWidthConstraint;
+
 @property (readwrite, strong) IBOutlet NSButton *shuffleButton;
+@property (readwrite, strong) IBOutlet NSLayoutConstraint *shuffleButtonWidthConstraint;
 
 @property (readwrite, strong) IBOutlet VLCVolumeSliderCommon * volumeSlider;
 @property (readwrite, strong) IBOutlet NSImageView *volumeTrackImageView;
@@ -49,6 +54,7 @@
 @property (readwrite, strong) IBOutlet NSButton *volumeUpButton;
 
 @property (readwrite, strong) IBOutlet NSButton *effectsButton;
+@property (readwrite, strong) IBOutlet NSLayoutConstraint *effectsButtonWidthConstraint;
 
 - (IBAction)stop:(id)sender;
 
@@ -62,7 +68,6 @@
 - (IBAction)repeat:(id)sender;
 
 - (void)setShuffle;
-- (IBAction)shuffle:(id)sender;
 
 - (IBAction)togglePlaylist:(id)sender;
 
