@@ -2,7 +2,7 @@
  * VLCStringUtility.m: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2002-2014 VLC authors and VideoLAN
- * $Id: 561b2e60a287afb0ea189d97fbff50d83a2a4849 $
+ * $Id: 16b80ebb107fd396c3b32e6078ec850b13c2f8de $
  *
  * Authors: Jon Lech Johansen <jon-vl@nanocrew.net>
  *          Christophe Massiot <massiot@via.ecp.fr>
@@ -533,7 +533,7 @@ NSString *toNSStr(const char *str) {
 NSImage *imageFromRes(NSString *o_id)
 {
     NSString *result = @"";
-    if (OSX_YOSEMITE || OSX_EL_CAPITAN || OSX_SIERRA) {
+    if (OSX_YOSEMITE_AND_HIGHER) {
         result = [result stringByAppendingString:@"ys-"];
     }
 
