@@ -2,7 +2,7 @@
  * VLCVoutWindowController.m: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2012-2014 VLC authors and VideoLAN
- * $Id: a0aaa18b3fa12195c60b985b3e1b1f5f46167433 $
+ * $Id: 4954eb85f0e86cb9bc597af86c190268e0bc2ca0 $
  *
  * Authors: Felix Paul Kühne <fkuehne -at- videolan -dot- org>
  *          David Fuhrmann <david dot fuhrmann at googlemail dot com>
@@ -169,7 +169,7 @@ static int WindowControl(vout_window_t *p_wnd, int i_query, va_list args)
             }
             default:
             {
-                msg_Warn(p_wnd, "unsupported control query");
+                msg_Warn(p_wnd, "unsupported control query: %i", i_query );
                 [voutController.lock unlock];
                 return VLC_EGENERIC;
             }
@@ -597,7 +597,6 @@ void WindowClose(vout_window_t *p_wnd)
     [[main bookmarks] updateCocoaWindowLevel:currentStatusWindowLevel];
     [[main trackSyncPanel] updateCocoaWindowLevel:currentStatusWindowLevel];
     [[main resumeDialog] updateCocoaWindowLevel:currentStatusWindowLevel];
-    [[[[[VLCMain sharedInstance] mainWindow] fspanel] window] setLevel:currentStatusWindowLevel];
 }
 
 @end
