@@ -2,7 +2,7 @@
  * misc.h: code not specific to vlc
  *****************************************************************************
  * Copyright (C) 2003-2014 VLC authors and VideoLAN
- * $Id: 5c566eb15eca38eab86c6c2a4bdddd5d75e9f132 $
+ * $Id: fb3893b3cfedf73dae0517c4cb074a0f8d75e8e6 $
  *
  * Authors: Jon Lech Johansen <jon-vl@nanocrew.net>
  *          Felix Paul Kühne <fkuehne at videolan dot org>
@@ -68,20 +68,6 @@
 
 @end
 
-
-/*****************************************************************************
- * TimeLineSlider
- *****************************************************************************/
-
-@interface TimeLineSlider : NSSlider
-
-@property (readonly) CGFloat knobPosition;
-
-- (void)drawRect:(NSRect)rect;
-- (void)drawKnobInRect:(NSRect)knobRect;
-
-@end
-
 /*****************************************************************************
  * VLCVolumeSliderCommon
  *****************************************************************************/
