@@ -2,7 +2,7 @@
  * ncurses.c : NCurses interface for vlc
  *****************************************************************************
  * Copyright © 2001-2011 the VideoLAN team
- * $Id: 12c80ca827e688eccb1055471e5d243d3c6d2174 $
+ * $Id: 1c593f88714e4547a9a6d85ac5be042958a3ab49 $
  *
  * Authors: Sam Hocevar <sam@zoy.org>
  *          Laurent Aimar <fenrir@via.ecp.fr>
@@ -975,15 +975,15 @@ static int DrawPlaylist(intf_thread_t *intf, input_thread_t *input)
     for (int i = 0; i < sys->plist_entries; i++) {
         char c;
         playlist_item_t *current;
-        input_item_t *input = sys->plist[i]->item;
+        input_item_t *item = sys->plist[i]->item;
 
         PL_LOCK;
         current = playlist_CurrentPlayingItem(p_playlist);
 
-        if ((sys->node != NULL && input == sys->node) ||
-            (sys->node == NULL && current != NULL && input == current->p_input))
+        if ((sys->node != NULL && item == sys->node) ||
+            (sys->node == NULL && current != NULL && item == current->p_input))
             c = '*';
-        else if (current != NULL && current->p_input == input)
+        else if (current != NULL && current->p_input == item)
             c = '>';
         else
             c = ' ';
