@@ -2,7 +2,7 @@
  * playlist_model.cpp : Manage playlist model
  ****************************************************************************
  * Copyright (C) 2006-2011 the VideoLAN team
- * $Id: dd883062484c627d6dfc212506e9ae272dbab11a $
+ * $Id: 18c84cf7f8e5845afdd5caf10de033caf35a2a56 $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Ilkka Ollakkka <ileoo (at) videolan dot org>
@@ -644,7 +644,11 @@ void PLModel::processItemAppend( int i_pl_itemid, int i_pl_itemidparent )
     if ( newItem->inputItem() == THEMIM->currentInputItem() )
         emit currentIndexChanged( index( newItem, 0 ) );
 
-    if( latestSearch.isEmpty() ) return;
+    if( latestSearch.isEmpty() )
+    {
+        rebuild();
+        return;
+    }
     filter( latestSearch, index( rootItem, 0), false /*FIXME*/ );
 }
 
