@@ -2,7 +2,7 @@
  * menus.cpp : Qt menus
  *****************************************************************************
  * Copyright © 2006-2011 the VideoLAN team
- * $Id: cd3ac0898b8502d33a60d1d77b23a39a6d059937 $
+ * $Id: 6395a0a068fa9017fa0ba67a893ddf04e3be36f1 $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Jean-Baptiste Kempf <jb@videolan.org>
@@ -81,7 +81,6 @@ static QActionGroup *currentGroup;
 
 QMenu *VLCMenuBar::recentsMenu = NULL;
 QMenu *VLCMenuBar::audioDeviceMenu = NULL;
-QMenu *VLCMenuBar::ppMenu = NULL;
 QMenu *VLCMenuBar::rendererMenu = NULL;
 QActionGroup *VLCMenuBar::rendererGroup = NULL;
 
@@ -249,8 +248,6 @@ static int VideoAutoMenuBuilder( playlist_t *pl, input_thread_t *p_input,
     PUSH_VAR( "deinterlace" );
     PUSH_VAR( "deinterlace-mode" );
 
-    VLCMenuBar::ppMenu->setEnabled( p_object != NULL );
-
     if( p_object )
         vlc_object_release( p_object );
     return VLC_SUCCESS;
@@ -690,8 +687,6 @@ QMenu *VLCMenuBar::VideoMenu( intf_thread_t *p_intf, QMenu *current )
         /* Rendering modifiers */
         addActionWithSubmenu( current, "deinterlace", qtr( "&Deinterlace" ) );
         addActionWithSubmenu( current, "deinterlace-mode", qtr( "&Deinterlace mode" ) );
-        ppMenu = PPMenu( p_intf );
-        current->addMenu( ppMenu );
 
         current->addSeparator();
         /* Other actions */
@@ -1254,10 +1249,13 @@ void VLCMenuBar::UpdateItem( intf_thread_t *p_intf, QMenu *menu,
     }
 
     /* Check the type of the object variable */
-    /* This HACK is needed so we have a radio button for audio and video tracks
-       instread of a checkbox */
+    /* This HACK is needed so that we have:
+     *  - a radio button for audio/video tracks instread of a checkbox, and;
+     *  - an always enabled bookmark menu (even if there are no bookmarks)
+     **/
     if( !strcmp( psz_var, "audio-es" )
-     || !strcmp( psz_var, "video-es" ) )
+     || !strcmp( psz_var, "video-es" )
+     || !strcmp( psz_var, "bookmark" ) )
         i_type = VLC_VAR_INTEGER | VLC_VAR_HASCHOICE;
     else
         i_type = var_Type( p_object, psz_var );
@@ -1557,7 +1555,7 @@ void VLCMenuBar::updateAudioDevice( intf_thread_t * p_intf, audio_output_t *p_ao
 
     for( int i = 0; i < i_result; i++ )
     {
-        action = new QAction( qfue( names[i] ), NULL );
+        action = new QAction( qfue( names[i] ), actionGroup );
         action->setData( ids[i] );
         action->setCheckable( true );
         if( (selected && !strcmp( ids[i], selected ) ) ||
@@ -1619,7 +1617,6 @@ void VLCMenuBar::updateRecents( intf_thread_t *p_intf )
 
             recentsMenu->addSeparator();
             recentsMenu->addAction( qtr("&Clear"), rmrl, SLOT( clear() ) );
-            addDPStaticEntry( recentsMenu, qtr("&Save To Playlist"), "", SLOT( saveRecentsToPlaylist() ), "" );
             recentsMenu->setEnabled( true );
         }
     }
@@ -1653,30 +1650,3 @@ QMenu *VLCMenuBar::RendererMenu( intf_thread_t *p_intf )
 
     return submenu;
 }
-
-QMenu *VLCMenuBar::PPMenu( intf_thread_t *p_intf )
-{
-    int i_q = ExtVideo::getPostprocessing( p_intf );
-
-    QMenu *submenu = new QMenu( qtr("&Post processing") );
-
-    QActionGroup *actionGroup = new QActionGroup(submenu);
-    QAction *action;
-
-#define ADD_PP_ACTION( text, value ) \
-    action = new QAction( qtr(text), submenu ); \
-    action->setData( value ); \
-    action->setCheckable(true); \
-    if( value == i_q ) action->setChecked( true ); \
-    submenu->addAction( action ); \
-    actionGroup->addAction( action );
-
-    ADD_PP_ACTION( "Disable", -1 );
-    submenu->addSeparator();
-    ADD_PP_ACTION( "Lowest",  1 );
-    ADD_PP_ACTION( "Middle",  3 );
-    ADD_PP_ACTION( "Highest", 6 );
-
-    CONNECT( actionGroup, triggered( QAction *), ActionsManager::getInstance( p_intf ), PPaction( QAction * ) );
-    return submenu;
-}
