@@ -30,14 +30,78 @@
 #include <vlc_atomic.h>
 #include <vlc_filter.h>
 #include <vlc_plugin.h>
-#include "vlc_vaapi.h"
+#include "filters.h"
 
+/*******************
+ * Instance holder *
+ *******************/
+
+/* XXX: Static filters (like deinterlace) may not have access to a picture
+ * allocated by the vout if it's not the first filter in the chain. That vout
+ * picture is needed to get the VADisplay instance. Therefore, we store the
+ * fist vaapi instance set by a filter so that it can be re-usable by others
+ * filters. The instance is ref-counted, so there is no problem if the main
+ * filter is destroyed before the other ones. */
+static struct {
+    vlc_mutex_t lock;
+    struct vlc_vaapi_instance *inst;
+    filter_t *owner;
+} holder = { VLC_STATIC_MUTEX, NULL, NULL };
+
+struct vlc_vaapi_instance *
+vlc_vaapi_FilterHoldInstance(filter_t *filter, VADisplay *dpy)
+{
+
+    picture_t *pic = filter_NewPicture(filter);
+    if (!pic)
+        return NULL;
+
+    if (pic->format.i_chroma != VLC_CODEC_VAAPI_420)
+    {
+        picture_Release(pic);
+        return NULL;
+    }
+
+    struct vlc_vaapi_instance *va_inst = NULL;
+
+    vlc_mutex_lock(&holder.lock);
+    if (holder.inst != NULL)
+    {
+        va_inst = holder.inst;
+        *dpy = vlc_vaapi_HoldInstance(holder.inst);
+    }
+    else
+    {
+        holder.owner = filter;
+        holder.inst = va_inst = pic->p_sys ?
+            vlc_vaapi_PicSysHoldInstance(pic->p_sys, dpy) : NULL;
+    }
+    vlc_mutex_unlock(&holder.lock);
+    picture_Release(pic);
+
+    return va_inst;
+}
+
+void
+vlc_vaapi_FilterReleaseInstance(filter_t *filter,
+                                struct vlc_vaapi_instance *va_inst)
+{
+    vlc_vaapi_ReleaseInstance(va_inst);
+    vlc_mutex_lock(&holder.lock);
+    if (filter == holder.owner)
+    {
+        holder.inst = NULL;
+        holder.owner = NULL;
+    }
+    vlc_mutex_unlock(&holder.lock);
+}
 /********************************
  * Common structures and macros *
  ********************************/
 
 struct  va_filter_desc
 {
+    struct vlc_vaapi_instance *inst;
     VADisplay           dpy;
     VAConfigID          conf;
     VAContextID         ctx;
@@ -156,18 +220,21 @@ struct  basic_filter_data
 
 struct  deint_mode
 {
-    char const                  name[5];
+    char                        name[5];
     VAProcDeinterlacingType     type;
+    bool                        b_double_rate;
 };
 
 static struct deint_mode const  deint_modes[] =
 {
-    { "x",     VAProcDeinterlacingMotionAdaptive },
-    { "x",     VAProcDeinterlacingMotionCompensated },
-    { "bob",   VAProcDeinterlacingBob },
-    { "mean",  VAProcDeinterlacingWeave }
+    { "x",     VAProcDeinterlacingMotionAdaptive,     true },
+    { "x",     VAProcDeinterlacingMotionCompensated,  true },
+    { "bob",   VAProcDeinterlacingBob,                true },
+    { "mean",  VAProcDeinterlacingWeave,              false }
 };
 
+#define METADATA_SIZE 3
+
 struct  deint_data
 {
     struct
@@ -183,6 +250,15 @@ struct  deint_data
         VASurfaceID *   surfaces;
         unsigned int    sz;
     } backward_refs, forward_refs;
+
+    struct
+    {
+        mtime_t date;
+        int     i_nb_fields;
+    } meta[METADATA_SIZE];
+
+    bool                b_double_rate;
+    unsigned int        cur_frame;
 };
 
 /********************
@@ -298,14 +374,15 @@ Open(filter_t * filter,
     filter_sys->va.conf = VA_INVALID_ID;
     filter_sys->va.ctx = VA_INVALID_ID;
     filter_sys->va.buf = VA_INVALID_ID;
-    filter_sys->va.dpy = vlc_vaapi_GetInstance();
-    if (!filter_sys->va.dpy)
+    filter_sys->va.inst =
+        vlc_vaapi_FilterHoldInstance(filter, &filter_sys->va.dpy);
+    if (!filter_sys->va.inst)
         goto error;
 
     filter_sys->dest_pics =
-        vlc_vaapi_PoolNew(VLC_OBJECT(filter), filter_sys->va.dpy,
-                          DEST_PICS_POOL_SZ, &filter_sys->va.surface_ids,
-                          &filter->fmt_out.video,
+        vlc_vaapi_PoolNew(VLC_OBJECT(filter), filter_sys->va.inst,
+                          filter_sys->va.dpy, DEST_PICS_POOL_SZ,
+                          &filter_sys->va.surface_ids, &filter->fmt_out.video,
                           VA_RT_FORMAT_YUV420, VA_FOURCC_NV12);
     if (!filter_sys->dest_pics)
         goto error;
@@ -376,20 +453,21 @@ error:
     if (filter_sys->va.conf != VA_INVALID_ID)
         vlc_vaapi_DestroyConfig(VLC_OBJECT(filter),
                                 filter_sys->va.dpy, filter_sys->va.conf);
-    if (filter_sys->va.dpy)
-        vlc_vaapi_ReleaseInstance(filter_sys->va.dpy);
+    if (filter_sys->va.inst)
+        vlc_vaapi_FilterReleaseInstance(filter, filter_sys->va.inst);
     free(filter_sys);
     return VLC_EGENERIC;
 }
 
 static void
-Close(vlc_object_t * obj, filter_sys_t * filter_sys)
+Close(filter_t *filter, filter_sys_t * filter_sys)
 {
+    vlc_object_t * obj = VLC_OBJECT(filter);
     picture_pool_Release(filter_sys->dest_pics);
     vlc_vaapi_DestroyBuffer(obj, filter_sys->va.dpy, filter_sys->va.buf);
     vlc_vaapi_DestroyContext(obj, filter_sys->va.dpy, filter_sys->va.ctx);
     vlc_vaapi_DestroyConfig(obj, filter_sys->va.dpy, filter_sys->va.conf);
-    vlc_vaapi_ReleaseInstance(filter_sys->va.dpy);
+    vlc_vaapi_FilterReleaseInstance(filter, filter_sys->va.inst);
     free(filter_sys);
 }
 
@@ -591,7 +669,7 @@ CloseAdjust(vlc_object_t * obj)
         var_Destroy(obj, adjust_params_names[i]);
     }
     free(filter_sys->p_data);
-    Close(obj, filter_sys);
+    Close(filter, filter_sys);
 }
 
 /***************************
@@ -725,7 +803,7 @@ CloseBasicFilter(vlc_object_t * obj)
     var_Destroy(obj, p_data->sigma.psz_name);
     free(p_data->sigma.psz_name);
     free(p_data);
-    Close(obj, filter_sys);
+    Close(filter, filter_sys);
 }
 
 /*************************
@@ -746,6 +824,20 @@ Deinterlace_UpdateHistory(struct deint_data * p_deint_data, picture_t * src)
     return *p_deint_data->history.pp_cur_pic;
 }
 
+static void
+Deinterlace_UpdateFilterParams(void * p_data, void * va_params)
+{
+    struct deint_data *const    p_deint_data = p_data;
+    VAProcFilterParameterBufferDeinterlacing *const      p_va_params = va_params;
+
+    p_va_params->flags =
+        p_deint_data->history.pp_cur_pic[0]->b_top_field_first ?
+        0 : VA_DEINTERLACING_BOTTOM_FIELD_FIRST;
+    if (p_deint_data->cur_frame ==
+        (p_deint_data->history.pp_cur_pic[0]->b_top_field_first ? 1 : 0))
+        p_va_params->flags |= VA_DEINTERLACING_BOTTOM_FIELD;
+}
+
 static void
 Deinterlace_UpdateReferenceFrames(void * p_data)
 {
@@ -776,10 +868,6 @@ Deinterlace_UpdatePipelineParams
 {
     struct deint_data *const    p_deint_data = p_data;
 
-    pipeline_param->filter_flags =
-        p_deint_data->history.pp_cur_pic[0]->b_top_field_first ?
-        0 : VA_DEINTERLACING_BOTTOM_FIELD_FIRST;
-
     pipeline_param->backward_references = p_deint_data->backward_refs.surfaces;
     pipeline_param->forward_references = p_deint_data->forward_refs.surfaces;
     pipeline_param->num_backward_references = p_deint_data->backward_refs.sz;
@@ -797,7 +885,8 @@ Deinterlace(filter_t * filter, picture_t * src)
         return NULL;
 
     picture_t *const    dest =
-        Filter(filter, src, NULL,
+        Filter(filter, src,
+               Deinterlace_UpdateFilterParams,
                Deinterlace_UpdateReferenceFrames,
                Deinterlace_UpdatePipelineParams);
 
@@ -807,6 +896,90 @@ Deinterlace(filter_t * filter, picture_t * src)
     return dest;
 }
 
+static picture_t *
+DeinterlaceX2(filter_t * filter, picture_t * src)
+{
+    filter_sys_t *const         filter_sys = filter->p_sys;
+    struct deint_data *const    p_deint_data = filter_sys->p_data;
+    const video_format_t *      fmt = &filter->fmt_out.video;
+
+    /* TODO: could use the meta array and calculation from deinterlace/common
+       but then it would also be appropriate to use the picture history array
+       too and the callback system...so a rewrite of this module basically.*/
+    for (unsigned int i = 1; i < METADATA_SIZE; ++i)
+        p_deint_data->meta[i-1] = p_deint_data->meta[i];
+    p_deint_data->meta[METADATA_SIZE-1].date        = src->date;
+    p_deint_data->meta[METADATA_SIZE-1].i_nb_fields = src->i_nb_fields;
+
+    picture_t * cur = Deinterlace_UpdateHistory(p_deint_data, src);
+    if (p_deint_data->history.num_pics < p_deint_data->history.sz)
+        return NULL;
+
+    mtime_t i_field_dur = 0;
+    unsigned int i = 0;
+    for ( ; i < METADATA_SIZE-1; i ++)
+        if (p_deint_data->meta[i].date > VLC_TS_INVALID)
+            break;
+    if (i < METADATA_SIZE-1) {
+        unsigned int i_fields_total = 0;
+        for (unsigned int j = i; j < METADATA_SIZE-1; ++j)
+            i_fields_total += p_deint_data->meta[j].i_nb_fields;
+        i_field_dur = (src->date - p_deint_data->meta[i].date) / i_fields_total;
+    }
+    else if (fmt->i_frame_rate_base)
+        i_field_dur = CLOCK_FREQ * fmt->i_frame_rate_base / fmt->i_frame_rate;
+
+    picture_t *dest[2] = {NULL, NULL};
+    for (i = 0; i < 2; ++i)
+    {
+        p_deint_data->cur_frame = i;
+        dest[i] = Filter(filter, cur,
+                         Deinterlace_UpdateFilterParams,
+                         Deinterlace_UpdateReferenceFrames,
+                         Deinterlace_UpdatePipelineParams);
+        if (!dest[i])
+           goto error;
+
+        dest[i]->b_progressive = true;
+        dest[i]->i_nb_fields = 1;
+    }
+
+    dest[0]->p_next = dest[1];
+    dest[0]->date = cur->date;
+    if (dest[0]->date > VLC_TS_INVALID)
+        dest[1]->date = dest[0]->date + i_field_dur;
+    else
+        dest[1]->date = VLC_TS_INVALID;
+
+    return dest[0];
+
+error:
+    for (i = 0; i < 2; ++i)
+        if (dest[i])
+            picture_Release(dest[i]);
+
+    return NULL;
+}
+
+static void
+Deinterlace_Flush(filter_t *filter)
+{
+    struct deint_data *const    p_deint_data = filter->p_sys->p_data;
+
+    while (p_deint_data->history.num_pics)
+    {
+        picture_t *     pic =
+            p_deint_data->history.pp_pics[--p_deint_data->history.num_pics];
+        picture_Release(pic);
+    }
+
+    for (unsigned int i = 0; i < METADATA_SIZE; ++i)
+    {
+        p_deint_data->meta[i].date = VLC_TS_INVALID;
+        p_deint_data->meta[i].i_nb_fields = 2;
+    }
+}
+
 static inline bool
 OpenDeinterlace_IsValidType(filter_t * filter,
                             VAProcDeinterlacingType const caps[],
@@ -822,7 +995,7 @@ OpenDeinterlace_IsValidType(filter_t * filter,
 
 static inline int
 OpenDeinterlace_GetMode(filter_t * filter, char const * deint_mode,
-                        VAProcDeinterlacingType * p_deint_mode,
+                        struct deint_mode * p_deint_mode,
                         VAProcDeinterlacingType const caps[],
                         unsigned int num_caps)
 {
@@ -836,7 +1009,7 @@ OpenDeinterlace_GetMode(filter_t * filter, char const * deint_mode,
                 if (OpenDeinterlace_IsValidType(filter, caps, num_caps,
                                                 deint_modes + i))
                 {
-                    *p_deint_mode = deint_modes[i].type;
+                    *p_deint_mode = deint_modes[i];
                     msg_Dbg(filter, "using %s deinterlace method",
                             deint_modes[i].name);
                     return VLC_SUCCESS;
@@ -850,7 +1023,7 @@ OpenDeinterlace_GetMode(filter_t * filter, char const * deint_mode,
         if (OpenDeinterlace_IsValidType(filter, caps, num_caps,
                                         deint_modes + i))
         {
-            *p_deint_mode = deint_modes[i].type;
+            *p_deint_mode = deint_modes[i];
             if (fallback)
                 msg_Info(filter, "%s algorithm not available, falling back to "
                          "%s algorithm", deint_mode, deint_modes[i].name);
@@ -873,7 +1046,8 @@ OpenDeinterlace_InitFilterParams(filter_t * filter, void * p_data,
                                  void ** pp_va_params,
                                  uint32_t * p_va_param_sz,
                                  uint32_t * p_num_va_params)
-{ VLC_UNUSED(p_data);
+{
+    struct deint_data *const    p_deint_data = p_data;
     filter_sys_t *const         filter_sys = filter->p_sys;
     VAProcDeinterlacingType     caps[VAProcDeinterlacingCount];
     unsigned int                num_caps = VAProcDeinterlacingCount;
@@ -885,12 +1059,12 @@ OpenDeinterlace_InitFilterParams(filter_t * filter, void * p_data,
                                            &caps, &num_caps))
         return VLC_EGENERIC;
 
-    VAProcDeinterlacingType     va_mode;
-    char *const                 psz_deint_mode =
+    struct deint_mode   deint_mode;
+    char *const         psz_deint_mode =
         var_InheritString(filter, "deinterlace-mode");
 
     int ret = OpenDeinterlace_GetMode(filter, psz_deint_mode,
-                                      &va_mode, caps, num_caps);
+                                      &deint_mode, caps, num_caps);
     free(psz_deint_mode);
     if (ret)
         return VLC_EGENERIC;
@@ -905,9 +1079,11 @@ OpenDeinterlace_InitFilterParams(filter_t * filter, void * p_data,
         return VLC_ENOMEM;
 
     p_va_param->type = VAProcFilterDeinterlacing;
-    p_va_param->algorithm = va_mode;
+    p_va_param->algorithm = deint_mode.type;
     *pp_va_params = p_va_param;
 
+    p_deint_data->b_double_rate = deint_mode.b_double_rate;
+
     return VLC_SUCCESS;
 }
 
@@ -961,7 +1137,17 @@ OpenDeinterlace(vlc_object_t * obj)
              OpenDeinterlace_InitFilterParams, OpenDeinterlace_InitHistory))
         goto error;
 
-    filter->pf_video_filter = Deinterlace;
+    if (p_data->b_double_rate)
+        filter->pf_video_filter = DeinterlaceX2;
+    else
+        filter->pf_video_filter = Deinterlace;
+    filter->pf_flush = Deinterlace_Flush;
+
+    for (unsigned int i = 0; i < METADATA_SIZE; ++i)
+    {
+        p_data->meta[i].date = VLC_TS_INVALID;
+        p_data->meta[i].i_nb_fields = 2;
+    }
 
     return VLC_SUCCESS;
 
@@ -990,7 +1176,7 @@ CloseDeinterlace(vlc_object_t * obj)
         free(p_data->history.pp_pics);
     }
     free(p_data);
-    Close(obj, filter_sys);
+    Close(filter, filter_sys);
 }
 
 /*********************
@@ -1019,9 +1205,9 @@ vlc_module_begin()
                          "Set the Denoise strength, between 0 and 2. "
                             "Defaults to 1.",
                          false)
-    add_shortcut("denoise")
+    add_shortcut("denoise", "sharpen")
 
     add_submodule()
-    set_callbacks(OpenBasicFilter, CloseBasicFilter)
-    add_shortcut("sharpen")
+    set_capability("video converter", 10)
+    set_callbacks(vlc_vaapi_OpenChroma, vlc_vaapi_CloseChroma)
 vlc_module_end()
