@@ -86,7 +86,7 @@ static int OpenDecoder ( vlc_object_t *p_this )
     p_dec->pf_decode = DecodeBlock;
 
     /* */
-    es_format_Init( &p_dec->fmt_out, VIDEO_ES, VLC_CODEC_I420 );
+    p_dec->fmt_out.i_codec = VLC_CODEC_I420;
     p_dec->fmt_out.video.i_width = 100;
     p_dec->fmt_out.video.i_height = 100;
     p_dec->fmt_out.video.i_sar_num = 1;
