@@ -2,7 +2,7 @@
  * mpegvideo.c: parse and packetize an MPEG1/2 video stream
  *****************************************************************************
  * Copyright (C) 2001-2006 VLC authors and VideoLAN
- * $Id: b716115320ab1f864db483e96947925384a81826 $
+ * $Id: a538582322030eccdc220976fe20bea0f10faa5c $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Eric Petit <titer@videolan.org>
@@ -418,6 +418,8 @@ static block_t *ParseMPEGBlock( decoder_t *p_dec, block_t *p_frag )
         }
 
         p_pic = block_ChainGather( p_sys->p_frame );
+        if( p_pic == NULL )
+            return p_pic;
 
         if( b_eos )
             p_pic->i_flags |= BLOCK_FLAG_END_OF_SEQUENCE;
