@@ -2,7 +2,7 @@
  * marq.c : marquee display video plugin for vlc
  *****************************************************************************
  * Copyright (C) 2003-2008 VLC authors and VideoLAN
- * $Id: 1af990c884a6b4a47f4db3c3cbf2b8351b013174 $
+ * $Id: 1834e57f55e0ae21ef8ce399d8f282e11a39c23c $
  *
  * Authors: Mark Moriarty
  *          Sigmund Augdal Helberg <dnumgis@videolan.org>
@@ -272,7 +272,6 @@ static subpicture_t *Filter( filter_t *p_filter, mtime_t date )
 {
     filter_sys_t *p_sys = p_filter->p_sys;
     subpicture_t *p_spu = NULL;
-    video_format_t fmt;
 
     vlc_mutex_lock( &p_sys->lock );
     if( p_sys->last_time + p_sys->i_refresh > date )
@@ -303,13 +302,10 @@ static subpicture_t *Filter( filter_t *p_filter, mtime_t date )
     if( !p_spu )
         goto out;
 
-    memset( &fmt, 0, sizeof(video_format_t) );
-    fmt.i_chroma = VLC_CODEC_TEXT;
-    fmt.i_width = fmt.i_height = 0;
-    fmt.i_x_offset = 0;
-    fmt.i_y_offset = 0;
-    fmt.i_sar_den = fmt.i_sar_num = 1;
-    p_spu->p_region = subpicture_region_New( &fmt );
+    video_format_t vfmt;
+    video_format_Init( &vfmt, VLC_CODEC_TEXT );
+    vfmt.i_sar_den = vfmt.i_sar_num = 1;
+    p_spu->p_region = subpicture_region_New( &vfmt );
     if( !p_spu->p_region )
     {
         subpicture_Delete( p_spu );
