@@ -2,7 +2,7 @@
  * bridge.c: bridge stream output module
  *****************************************************************************
  * Copyright (C) 2005-2008 VLC authors and VideoLAN
- * $Id: 4e140f054a98bdf4bf671df3d13ceeb8e1704c13 $
+ * $Id: 7449c3dbc3753afe4156767a2d20902e5ef8c377 $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Antoine Cellerier <dionoea at videolan dot org>
@@ -448,7 +448,7 @@ static void CloseIn( vlc_object_t * p_this )
 struct sout_stream_id_sys_t
 {
     sout_stream_id_sys_t *id;
-    int i_cat; /* es category. Used for placeholder option */
+    enum es_format_category_e i_cat; /* es category. Used for placeholder option */
 };
 
 static sout_stream_id_sys_t * AddIn( sout_stream_t *p_stream, const es_format_t *p_fmt )
