@@ -2,7 +2,7 @@
  * spu.c: transcoding stream output module (spu)
  *****************************************************************************
  * Copyright (C) 2003-2009 VLC authors and VideoLAN
- * $Id: b5ef8db30948526aeb0596b8e354bdbd42624117 $
+ * $Id: ccdf3fb155a6545e2fa98bfccc4825fe35cd3744 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Gildas Bazin <gbazin@videolan.org>
@@ -80,7 +80,6 @@ int transcode_spu_new( sout_stream_t *p_stream, sout_stream_id_sys_t *id )
     id->p_decoder->pf_spu_buffer_new = spu_new_buffer;
     id->p_decoder->pf_queue_sub = decoder_queue_sub;
     id->p_decoder->p_queue_ctx = id;
-    id->p_decoder->p_owner = (decoder_owner_sys_t *)p_stream;
     /* id->p_decoder->p_cfg = p_sys->p_spu_cfg; */
 
     id->p_decoder->p_module =
@@ -113,7 +112,7 @@ int transcode_spu_new( sout_stream_t *p_stream, sout_stream_id_sys_t *id )
     }
 
     if( !p_sys->p_spu )
-        p_sys->p_spu = spu_Create( p_stream );
+        p_sys->p_spu = spu_Create( p_stream, NULL );
 
     return VLC_SUCCESS;
 }
