@@ -2,7 +2,7 @@
  * freetype.c : Put text on the video, using freetype2
  *****************************************************************************
  * Copyright (C) 2002 - 2015 VLC authors and VideoLAN
- * $Id: 823dbd0dbb344254791c8f62b8d39a364417ae44 $
+ * $Id: 39994a01b0bc30385927dd06adb20d87d9896ba7 $
  *
  * Authors: Sigmund Augdal Helberg <dnumgis@videolan.org>
  *          Gildas Bazin <gbazin@videolan.org>
@@ -864,14 +864,13 @@ static inline int RenderAXYZ( filter_t *p_filter,
         for( line_desc_t *p_line = p_line_head; p_line != NULL; p_line = p_line->p_next )
         {
             int i_align_left = i_margin;
-            if( p_line->i_width < i_text_width )
+            if( p_line->i_width < i_text_width &&
+               (p_region->i_align & (SUBPICTURE_ALIGN_LEAVETEXT|SUBPICTURE_ALIGN_LEFT)) == 0 )
             {
                 /* Left offset to take into account alignment */
-                if( (p_region->i_align & 0x3) == SUBPICTURE_ALIGN_RIGHT )
+                if( p_region->i_align & SUBPICTURE_ALIGN_RIGHT )
                     i_align_left += ( i_text_width - p_line->i_width );
-                else if( (p_region->i_align & 0x10) == SUBPICTURE_ALIGN_LEAVETEXT)
-                    i_align_left = i_margin; /* Keep it the way it is */
-                else if( (p_region->i_align & 0x3) != SUBPICTURE_ALIGN_LEFT )
+                else /* center */
                     i_align_left += ( i_text_width - p_line->i_width ) / 2;
             }
             int i_align_top = i_margin;
@@ -1132,10 +1131,22 @@ static int Render( filter_t *p_filter, subpicture_region_t *p_region_out,
     line_desc_t *p_lines = NULL;
 
     uint32_t *pi_k_durations   = NULL;
+    unsigned i_max_width = p_filter->fmt_out.video.i_visible_width;
+    if( p_region_in->i_max_width > 0 && (unsigned) p_region_in->i_max_width < i_max_width )
+        i_max_width = p_region_in->i_max_width;
+    else if( p_region_in->i_x > 0 && (unsigned)p_region_in->i_x < i_max_width )
+        i_max_width -= p_region_in->i_x;
+
+    unsigned i_max_height = p_filter->fmt_out.video.i_visible_height;
+    if( p_region_in->i_max_height > 0 && (unsigned) p_region_in->i_max_height < i_max_height )
+        i_max_height = p_region_in->i_max_height;
+    else if( p_region_in->i_y > 0 && (unsigned)p_region_in->i_y < i_max_height )
+        i_max_height -= p_region_in->i_y;
 
     rv = LayoutText( p_filter,
-                     &p_lines, &bbox, &i_max_face_height,
-                     psz_text, pp_styles, pi_k_durations, i_text_length, p_region_in->b_gridmode );
+                     psz_text, pp_styles, pi_k_durations, i_text_length,
+                     p_region_in->b_gridmode, p_region_in->b_balanced_text,
+                     i_max_width, i_max_height, &p_lines, &bbox, &i_max_face_height );
 
     p_region_out->i_x = p_region_in->i_x;
     p_region_out->i_y = p_region_in->i_y;
