@@ -2,7 +2,7 @@
  * filters.c : audio output filters management
  *****************************************************************************
  * Copyright (C) 2002-2007 VLC authors and VideoLAN
- * $Id: 400d6e72f73cb15c076941ae3be27646e44cd93d $
+ * $Id: f74ac6563c61a2e0e6a4c952f9a55fbb966efb6c $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -45,23 +45,42 @@
 static filter_t *CreateFilter (vlc_object_t *obj, const char *type,
                                const char *name, filter_owner_sys_t *owner,
                                const audio_sample_format_t *infmt,
-                               const audio_sample_format_t *outfmt)
+                               const audio_sample_format_t *outfmt,
+                               config_chain_t *cfg, bool const_fmt)
 {
     filter_t *filter = vlc_custom_create (obj, sizeof (*filter), type);
     if (unlikely(filter == NULL))
         return NULL;
 
     filter->owner.sys = owner;
+    filter->p_cfg = cfg;
     filter->fmt_in.audio = *infmt;
     filter->fmt_in.i_codec = infmt->i_format;
     filter->fmt_out.audio = *outfmt;
     filter->fmt_out.i_codec = outfmt->i_format;
+
+#ifndef NDEBUG
+    /* Assure that infmt/oufmt are well prepared and that channels
+     * configurations are valid*/
+    if( infmt->i_physical_channels != 0 )
+        assert( aout_FormatNbChannels( infmt ) == infmt->i_channels );
+    if( outfmt->i_physical_channels != 0 )
+        assert( aout_FormatNbChannels( outfmt ) == outfmt->i_channels );
+#endif
+
     filter->p_module = module_need (filter, type, name, false);
-    if (filter->p_module == NULL)
+
+#ifndef NDEBUG
+    if (filter->p_module == NULL || const_fmt)
     {
         /* If probing failed, formats shall not have been modified. */
         assert (AOUT_FMTS_IDENTICAL(&filter->fmt_in.audio, infmt));
         assert (AOUT_FMTS_IDENTICAL(&filter->fmt_out.audio, outfmt));
+    }
+#endif
+
+    if (filter->p_module == NULL)
+    {
         vlc_object_release (filter);
         filter = NULL;
     }
@@ -74,7 +93,8 @@ static filter_t *FindConverter (vlc_object_t *obj,
                                 const audio_sample_format_t *infmt,
                                 const audio_sample_format_t *outfmt)
 {
-    return CreateFilter (obj, "audio converter", NULL, NULL, infmt, outfmt);
+    return CreateFilter (obj, "audio converter", NULL, NULL, infmt, outfmt,
+                         NULL, true);
 }
 
 static filter_t *FindResampler (vlc_object_t *obj,
@@ -82,7 +102,7 @@ static filter_t *FindResampler (vlc_object_t *obj,
                                 const audio_sample_format_t *outfmt)
 {
     return CreateFilter (obj, "audio resampler", "$audio-resampler", NULL,
-                         infmt, outfmt);
+                         infmt, outfmt, NULL, true);
 }
 
 /**
@@ -143,7 +163,7 @@ static int aout_FiltersPipelineCreate(vlc_object_t *obj, filter_t **filters,
 
     /* Remix channels */
     if (infmt->i_physical_channels != outfmt->i_physical_channels
-     || infmt->i_original_channels != outfmt->i_original_channels)
+     || infmt->i_chan_mode != outfmt->i_chan_mode)
     {   /* Remixing currently requires FL32... TODO: S16N */
         if (input.i_format != VLC_CODEC_FL32)
         {
@@ -168,7 +188,7 @@ static int aout_FiltersPipelineCreate(vlc_object_t *obj, filter_t **filters,
         output.i_format = input.i_format;
         output.i_rate = input.i_rate;
         output.i_physical_channels = outfmt->i_physical_channels;
-        output.i_original_channels = outfmt->i_original_channels;
+        output.i_chan_mode = outfmt->i_chan_mode;
         aout_FormatPrepare (&output);
 
         filter_t *f = FindConverter (obj, &input, &output);
@@ -336,7 +356,7 @@ static int VisualizationCallback (vlc_object_t *obj, const char *var,
 }
 
 vout_thread_t *aout_filter_RequestVout (filter_t *filter, vout_thread_t *vout,
-                                        video_format_t *fmt)
+                                        const video_format_t *fmt)
 {
     /* NOTE: This only works from aout_filters_t.
      * If you want to use visualization filters from another place, you will
@@ -355,7 +375,8 @@ vout_thread_t *aout_filter_RequestVout (filter_t *filter, vout_thread_t *vout,
 static int AppendFilter(vlc_object_t *obj, const char *type, const char *name,
                         aout_filters_t *restrict filters, const void *owner,
                         audio_sample_format_t *restrict infmt,
-                        const audio_sample_format_t *restrict outfmt)
+                        const audio_sample_format_t *restrict outfmt,
+                        config_chain_t *cfg)
 {
     const unsigned max = sizeof (filters->tab) / sizeof (filters->tab[0]);
     if (filters->count >= max)
@@ -365,7 +386,7 @@ static int AppendFilter(vlc_object_t *obj, const char *type, const char *name,
     }
 
     filter_t *filter = CreateFilter (obj, type, name,
-                                     (void *)owner, infmt, outfmt);
+                                     (void *)owner, infmt, outfmt, cfg, false);
     if (filter == NULL)
     {
         msg_Err (obj, "cannot add user %s \"%s\" (skipped)", type, name);
@@ -389,6 +410,52 @@ static int AppendFilter(vlc_object_t *obj, const char *type, const char *name,
     return 0;
 }
 
+static int AppendRemapFilter(vlc_object_t *obj, aout_filters_t *restrict filters,
+                             audio_sample_format_t *restrict infmt,
+                             const audio_sample_format_t *restrict outfmt,
+                             const int *wg4_remap)
+{
+    char *name;
+    config_chain_t *cfg;
+
+    /* The remap audio filter use a different order than wg4 */
+    static const uint8_t wg4_to_remap[] = { 0, 2, 6, 7, 3, 5, 4, 1, 8 };
+    int remap[AOUT_CHAN_MAX];
+    bool needed = false;
+    for (int i = 0; i < AOUT_CHAN_MAX; ++i)
+    {
+        if (wg4_remap[i] != i)
+            needed = true;
+        remap[i] = wg4_remap[i] >= 0 ? wg4_to_remap[wg4_remap[i]] : -1;
+    }
+    if (!needed)
+        return 0;
+
+    char *str;
+    int ret = asprintf(&str, "remap{channel-left=%d,channel-right=%d,"
+                       "channel-middleleft=%d,channel-middleright=%d,"
+                       "channel-rearleft=%d,channel-rearright=%d,"
+                       "channel-rearcenter=%d,channel-center=%d,"
+                       "channel-lfe=%d,normalize=false}",
+                       remap[0], remap[1], remap[2], remap[3], remap[4],
+                       remap[5], remap[6], remap[7], remap[8]);
+    if (ret == -1)
+        return -1;
+
+    free(config_ChainCreate(&name, &cfg, str));
+    if (name != NULL && cfg != NULL)
+        ret = AppendFilter(obj, "audio filter", name, filters,
+                           NULL, infmt, outfmt, cfg);
+    else
+        ret = -1;
+
+    free(str);
+    free(name);
+    if (cfg)
+        config_ChainDestroy(cfg);
+    return ret;
+}
+
 #undef aout_FiltersNew
 /**
  * Sets a chain of audio filters up.
@@ -396,6 +463,9 @@ static int AppendFilter(vlc_object_t *obj, const char *type, const char *name,
  * \param infmt chain input format [IN]
  * \param outfmt chain output format [IN]
  * \param request_vout visualization video output request callback
+ * \param remap a const array of size AOUT_CHAN_MAX or NULL. If not NULL, a
+ * remap audio filter will be inserted to remap channels according to the
+ * array. The array is in the WG4 order.
  * \return a filters chain or NULL on failure
  *
  * \note
@@ -407,7 +477,8 @@ static int AppendFilter(vlc_object_t *obj, const char *type, const char *name,
 aout_filters_t *aout_FiltersNew (vlc_object_t *obj,
                                  const audio_sample_format_t *restrict infmt,
                                  const audio_sample_format_t *restrict outfmt,
-                                 const aout_request_vout_t *request_vout)
+                                 const aout_request_vout_t *request_vout,
+                                 const int *remap)
 {
     aout_filters_t *filters = malloc (sizeof (*filters));
     if (unlikely(filters == NULL))
@@ -442,20 +513,45 @@ aout_filters_t *aout_FiltersNew (vlc_object_t *obj,
         }
         return filters;
     }
-    if (aout_FormatNbChannels(infmt) == 0 || aout_FormatNbChannels(outfmt) == 0)
+    if (aout_FormatNbChannels(outfmt) == 0)
     {
-        msg_Warn (obj, "No channel mask, cannot setup filters");
+        msg_Warn (obj, "No ouput channel mask, cannot setup filters");
         goto error;
     }
 
+    if (aout_FormatNbChannels(&input_format) == 0)
+    {
+        /* The input channel map is unknown, use the WAVE one and add a
+         * converter that will drop extra channels that are not handled by VLC
+         * */
+        msg_Info(obj, "unknown channel map, using the WAVE channel layout.");
+
+        assert(input_format.i_channels > 0);
+        audio_sample_format_t input_phys_format = input_format;
+        aout_SetWavePhysicalChannels(&input_phys_format);
+
+        filter_t *f = FindConverter (obj, &input_format, &input_phys_format);
+        if (f == NULL)
+        {
+            msg_Err (obj, "cannot find channel converter");
+            goto error;
+        }
+
+        input_format = input_phys_format;
+        filters->tab[filters->count++] = f;
+    }
+
     /* parse user filter lists */
     if (var_InheritBool (obj, "audio-time-stretch"))
     {
         if (AppendFilter(obj, "audio filter", "scaletempo",
-                         filters, NULL, &input_format, &output_format) == 0)
+                         filters, NULL, &input_format, &output_format, NULL) == 0)
             filters->rate_filter = filters->tab[filters->count - 1];
     }
 
+    if (remap != NULL)
+        AppendRemapFilter(obj, filters, &input_format, &output_format, remap);
+
     /* Now add user filters */
     char *str = var_InheritString (obj, "audio-filter");
     if (str != NULL)
@@ -464,7 +560,7 @@ aout_filters_t *aout_FiltersNew (vlc_object_t *obj,
         while ((name = strsep (&p, " :")) != NULL)
         {
             AppendFilter(obj, "audio filter", name, filters,
-                         NULL, &input_format, &output_format);
+                         NULL, &input_format, &output_format, NULL);
         }
         free (str);
     }
@@ -474,7 +570,7 @@ aout_filters_t *aout_FiltersNew (vlc_object_t *obj,
         char *visual = var_InheritString (obj, "audio-visual");
         if (visual != NULL && strcasecmp (visual, "none"))
             AppendFilter(obj, "visualization", visual, filters,
-                         request_vout, &input_format, &output_format);
+                         request_vout, &input_format, &output_format, NULL);
         free (visual);
     }
 
