@@ -2,7 +2,7 @@
  * output.c : internal management of output streams for the audio output
  *****************************************************************************
  * Copyright (C) 2002-2004 VLC authors and VideoLAN
- * $Id: 8a70cdfddcd43f6ecec7354be07b6f6270413836 $
+ * $Id: 6b1ddc7de217a17ea668a9730aaa3a1d3c497457 $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -171,6 +171,16 @@ static int FilterCallback (vlc_object_t *obj, const char *var,
     return VLC_SUCCESS;
 }
 
+static int StereoModeCallback (vlc_object_t *obj, const char *varname,
+                               vlc_value_t oldval, vlc_value_t newval, void *data)
+{
+    audio_output_t *aout = (audio_output_t *)obj;
+    (void)varname; (void)oldval; (void)newval; (void)data;
+
+    aout_RestartRequest (aout, AOUT_RESTART_STEREOMODE);
+    return 0;
+}
+
 #undef aout_New
 /**
  * Creates an audio output object and initializes an output module.
@@ -310,6 +320,13 @@ audio_output_t *aout_New (vlc_object_t *parent)
                             &val, &text);
         }
 
+    /* Stereo mode */
+    var_Create (aout, "stereo-mode", VLC_VAR_INTEGER | VLC_VAR_DOINHERIT);
+    var_AddCallback (aout, "stereo-mode", StereoModeCallback, NULL);
+    vlc_value_t txt;
+    txt.psz_string = _("Stereo audio mode");
+    var_Change (aout, "stereo-mode", VLC_VAR_SETTEXT, &txt, NULL);
+
     /* Equalizer */
     var_Create (aout, "equalizer-preamp", VLC_VAR_FLOAT | VLC_VAR_DOINHERIT);
     var_Create (aout, "equalizer-bands", VLC_VAR_STRING | VLC_VAR_DOINHERIT);
@@ -338,6 +355,7 @@ void aout_Destroy (audio_output_t *aout)
     var_DelCallback (aout, "mute", var_Copy, aout->obj.parent);
     var_SetFloat (aout, "volume", -1.f);
     var_DelCallback (aout, "volume", var_Copy, aout->obj.parent);
+    var_DelCallback (aout, "stereo-mode", StereoModeCallback, NULL);
     vlc_object_release (aout);
 }
 
@@ -367,10 +385,22 @@ static void aout_Destructor (vlc_object_t *obj)
  * \param fmt audio output stream format [IN/OUT]
  * \warning The caller must hold the audio output lock.
  */
-int aout_OutputNew (audio_output_t *aout, audio_sample_format_t *restrict fmt)
+int aout_OutputNew (audio_output_t *aout, audio_sample_format_t *restrict fmt,
+                    int *remap)
 {
     aout_OutputAssertLocked (aout);
 
+    int i_forced_stereo_mode = var_GetInteger (aout, "stereo-mode");
+    bool b_stereo_original = fmt->i_physical_channels == AOUT_CHANS_STEREO;
+    if (i_forced_stereo_mode != AOUT_VAR_CHAN_UNSET)
+    {
+        if (i_forced_stereo_mode == AOUT_VAR_CHAN_LEFT
+         || i_forced_stereo_mode == AOUT_VAR_CHAN_RIGHT)
+            fmt->i_physical_channels = AOUT_CHAN_CENTER;
+        else
+            fmt->i_physical_channels = AOUT_CHANS_STEREO;
+    }
+
     /* Ideally, the audio filters would be created before the audio output,
      * and the ideal audio format would be the output of the filters chain.
      * But that scheme would not really play well with digital pass-through. */
@@ -387,64 +417,73 @@ int aout_OutputNew (audio_output_t *aout, audio_sample_format_t *restrict fmt)
         return -1;
     }
 
+    /* Fill Stereo mode choices */
+    var_Change (aout, "stereo-mode", VLC_VAR_CLEARCHOICES, NULL, NULL);
+    vlc_value_t val, txt, default_val;
+    val.i_int = 0;
+    if (!b_stereo_original)
+    {
+        val.i_int = AOUT_VAR_CHAN_UNSET;
+        txt.psz_string = _("Original");
+        var_Change (aout, "stereo-mode", VLC_VAR_ADDCHOICE, &val, &txt);
+    }
+    if (fmt->i_chan_mode & AOUT_CHANMODE_DOLBYSTEREO)
+    {
+        val.i_int = AOUT_VAR_CHAN_DOLBYS;
+        txt.psz_string = _("Dolby Surround");
+    }
+    else
+    {
+        val.i_int = AOUT_VAR_CHAN_STEREO;
+        txt.psz_string = _("Stereo");
+    }
+    var_Change (aout, "stereo-mode", VLC_VAR_ADDCHOICE, &val, &txt);
+    default_val.i_int = b_stereo_original ? val.i_int : AOUT_VAR_CHAN_UNSET;
+
+    if (b_stereo_original)
+    {
+        val.i_int = AOUT_VAR_CHAN_LEFT;
+        txt.psz_string = _("Left");
+        var_Change (aout, "stereo-mode", VLC_VAR_ADDCHOICE, &val, &txt);
+        val.i_int = AOUT_VAR_CHAN_RIGHT;
+        txt.psz_string = _("Right");
+        var_Change (aout, "stereo-mode", VLC_VAR_ADDCHOICE, &val, &txt);
+    }
+    val.i_int = AOUT_VAR_CHAN_RSTEREO;
+    txt.psz_string = _("Reverse stereo");
+    var_Change (aout, "stereo-mode", VLC_VAR_ADDCHOICE, &val, &txt);
+
     /* The user may have selected a different channels configuration. */
-    var_AddCallback (aout, "stereo-mode", aout_ChannelsRestart, NULL);
-    switch (var_GetInteger (aout, "stereo-mode"))
+    switch (i_forced_stereo_mode)
     {
         case AOUT_VAR_CHAN_RSTEREO:
-            fmt->i_original_channels |= AOUT_CHAN_REVERSESTEREO;
+            remap[AOUT_CHANIDX_LEFT] = AOUT_CHANIDX_RIGHT;
+            remap[AOUT_CHANIDX_RIGHT] = AOUT_CHANIDX_LEFT;
             break;
         case AOUT_VAR_CHAN_STEREO:
-            fmt->i_original_channels = AOUT_CHANS_STEREO;
             break;
         case AOUT_VAR_CHAN_LEFT:
-            fmt->i_original_channels = AOUT_CHAN_LEFT;
+            remap[AOUT_CHANIDX_RIGHT] = AOUT_CHANIDX_DISABLE;
             break;
         case AOUT_VAR_CHAN_RIGHT:
-            fmt->i_original_channels = AOUT_CHAN_RIGHT;
+            remap[AOUT_CHANIDX_LEFT] = AOUT_CHANIDX_DISABLE;
             break;
         case AOUT_VAR_CHAN_DOLBYS:
-            fmt->i_original_channels = AOUT_CHANS_STEREO|AOUT_CHAN_DOLBYSTEREO;
+            fmt->i_chan_mode = AOUT_CHANMODE_DOLBYSTEREO;
             break;
         default:
-        {
-            if ((fmt->i_original_channels & AOUT_CHAN_PHYSMASK)
-                                                          != AOUT_CHANS_STEREO)
-                 break;
-
-            vlc_value_t val, txt;
-            val.i_int = 0;
-            var_Change (aout, "stereo-mode", VLC_VAR_DELCHOICE, &val, NULL);
-            if (fmt->i_original_channels & AOUT_CHAN_DOLBYSTEREO)
-            {
-                val.i_int = AOUT_VAR_CHAN_DOLBYS;
-                txt.psz_string = _("Dolby Surround");
-            }
-            else
-            {
-                val.i_int = AOUT_VAR_CHAN_STEREO;
-                txt.psz_string = _("Stereo");
-            }
-            var_Change (aout, "stereo-mode", VLC_VAR_ADDCHOICE, &val, &txt);
-            var_Change (aout, "stereo-mode", VLC_VAR_SETVALUE, &val, NULL);
-            val.i_int = AOUT_VAR_CHAN_LEFT;
-            txt.psz_string = _("Left");
-            var_Change (aout, "stereo-mode", VLC_VAR_ADDCHOICE, &val, &txt);
-            if (fmt->i_original_channels & AOUT_CHAN_DUALMONO)
+            if (b_stereo_original && fmt->i_chan_mode & AOUT_CHANMODE_DUALMONO)
             {   /* Go directly to the left channel. */
-                fmt->i_original_channels = AOUT_CHAN_LEFT;
-                var_Change (aout, "stereo-mode", VLC_VAR_SETVALUE, &val, NULL);
+                remap[AOUT_CHANIDX_RIGHT] = AOUT_CHANIDX_DISABLE;
+                default_val.i_int = val.i_int = AOUT_VAR_CHAN_LEFT;
             }
-            val.i_int = AOUT_VAR_CHAN_RIGHT;
-            txt.psz_string = _("Right");
-            var_Change (aout, "stereo-mode", VLC_VAR_ADDCHOICE, &val, &txt);
-            val.i_int = AOUT_VAR_CHAN_RSTEREO;
-            txt.psz_string = _("Reverse stereo");
-            var_Change (aout, "stereo-mode", VLC_VAR_ADDCHOICE, &val, &txt);
-        }
+            var_Change (aout, "stereo-mode", VLC_VAR_SETVALUE, &default_val,
+                        NULL);
+            break;
     }
 
     aout_FormatPrepare (fmt);
+    assert (aout_FormatNbChannels(fmt) > 0);
     assert (fmt->i_bytes_per_frame > 0 && fmt->i_frame_length > 0);
     aout_FormatPrint (aout, "output", fmt);
     return 0;
@@ -459,7 +498,6 @@ void aout_OutputDelete (audio_output_t *aout)
 {
     aout_OutputAssertLocked (aout);
 
-    var_DelCallback (aout, "stereo-mode", aout_ChannelsRestart, NULL);
     if (aout->stop != NULL)
         aout->stop (aout);
 }
