@@ -2,7 +2,7 @@
  * es_out_timeshift.c: Es Out timeshift.
  *****************************************************************************
  * Copyright (C) 2008 Laurent Aimar
- * $Id: c8fa798561a5ad68f90d6ff48f61d98ee4aac18b $
+ * $Id: ff5bd6bdbe1de2030108027d33230eba9e5af742 $
  *
  * Authors: Laurent Aimar < fenrir _AT_ videolan _DOT_ org>
  *
@@ -737,9 +737,6 @@ static int ControlLocked( es_out_t *p_out, int i_query, va_list args )
         return es_out_ControlModifyPcrSystem( p_sys->p_out, b_absolute, i_system );
     }
 
-    default:
-        msg_Err( p_sys->p_input, "Unknown es_out_Control query !" );
-        // ft
     /* Invalid queries for this es_out level */
     case ES_OUT_SET_ES_BY_ID:
     case ES_OUT_RESTART_ES_BY_ID:
@@ -747,6 +744,7 @@ static int ControlLocked( es_out_t *p_out, int i_query, va_list args )
     case ES_OUT_GET_ES_OBJECTS_BY_ID:
     case ES_OUT_SET_DELAY:
     case ES_OUT_SET_RECORD_STATE:
+    default:
         vlc_assert_unreachable();
         return VLC_EGENERIC;
     }
@@ -1634,8 +1632,6 @@ static void CmdCleanControl( ts_cmd_t *p_cmd )
             es_format_Clean( p_cmd->u.control.u.es_fmt.p_fmt );
             free( p_cmd->u.control.u.es_fmt.p_fmt );
         }
-        // ft
-    default:
         break;
     }
 }
