@@ -2,7 +2,7 @@
  * es_format.c : es_format_t helpers.
  *****************************************************************************
  * Copyright (C) 2008 VLC authors and VideoLAN
- * $Id: a436599058abc73f554ab419e8aa30ff70b1648b $
+ * $Id: b37a35418836708e7f25d050dadbde18a3b34b4d $
  *
  * Author: Laurent Aimar <fenrir@videolan.org>
  *
@@ -583,7 +583,7 @@ bool es_format_IsSimilar( const es_format_t *p_fmt1, const es_format_t *p_fmt2 )
         if( a1.i_rate != a2.i_rate ||
             a1.i_channels != a2.i_channels ||
             a1.i_physical_channels != a2.i_physical_channels ||
-            a1.i_original_channels != a2.i_original_channels )
+            a1.i_chan_mode != a2.i_chan_mode )
             return false;
         return true;
     }
