@@ -2,7 +2,7 @@
  * variables.c: routines for object variables handling
  *****************************************************************************
  * Copyright (C) 2002-2009 VLC authors and VideoLAN
- * $Id: f2e54784792e86090e3a4657ecc04c95ab2e32ec $
+ * $Id: d441684c06c93441037a19941c88f5d73e756b4c $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *
@@ -340,7 +340,7 @@ int var_Create( vlc_object_t *p_this, const char *psz_name, int i_type )
         case VLC_VAR_FLOAT:
             p_var->ops = &float_ops;
             p_var->val.f_float = 0.f;
-            p_var->min.f_float = FLT_MIN;
+            p_var->min.f_float = -FLT_MAX;
             p_var->max.f_float = FLT_MAX;
             break;
         case VLC_VAR_COORDS:
@@ -1378,7 +1378,7 @@ void DumpVariables(vlc_object_t *obj)
     vlc_mutex_unlock(&vlc_internals(obj)->var_lock);
 }
 
-static _Thread_local void *twalk_ctx;
+static thread_local void *twalk_ctx;
 
 static void TwalkGetNames(const void *data, const VISIT which, const int depth)
 {
@@ -1400,8 +1400,8 @@ char **var_GetAllNames(vlc_object_t *obj)
     DECL_ARRAY(char *) names;
     ARRAY_INIT(names);
 
-    vlc_mutex_lock(&priv->var_lock);
     twalk_ctx = &names;
+    vlc_mutex_lock(&priv->var_lock);
     twalk(priv->var_root, TwalkGetNames);
     vlc_mutex_unlock(&priv->var_lock);
 
