@@ -6,7 +6,7 @@
  * thread, and destroy a previously oppened video output thread.
  *****************************************************************************
  * Copyright (C) 2000-2007 VLC authors and VideoLAN
- * $Id: c1ddc6a4d512df02ce26a21b5a2121a393e561e5 $
+ * $Id: 2f11ebeec35357cd84ec1a88db07471f40e5e8bd $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Gildas Bazin <gbazin@videolan.org>
@@ -150,7 +150,7 @@ static vout_thread_t *VoutCreate(vlc_object_t *object,
     vout_IntfInit(vout);
 
     /* Initialize subpicture unit */
-    vout->p->spu = spu_Create(vout);
+    vout->p->spu = spu_Create(vout, vout);
 
     vout->p->title.show     = var_InheritBool(vout, "video-title-show");
     vout->p->title.timeout  = var_InheritInteger(vout, "video-title-timeout");
@@ -651,58 +651,19 @@ int vout_HideWindowMouse(vout_thread_t *vout, bool hide)
 }
 
 /* */
-static int FilterProxyCallback(vlc_object_t *p_this, char const *psz_var,
-                         vlc_value_t oldval, vlc_value_t newval,
-                         void *p_data)
+static int FilterRestartCallback(vlc_object_t *p_this, char const *psz_var,
+                                 vlc_value_t oldval, vlc_value_t newval,
+                                 void *p_data)
 {
-    (void) p_this; (void) oldval;
-    var_Set((filter_t *)p_data, psz_var, newval);
+    (void) p_this; (void) psz_var; (void) oldval; (void) newval;
+    vout_ControlChangeFilters((vout_thread_t *)p_data, NULL);
     return 0;
 }
 
-static void ThreadAddFilterCallbacks(vout_thread_t *vout, filter_t *filter)
-{
-    /* Duplicate every command variables from the filter, and add a proxy
-     * callback to trigger filters events from the vout. */
-
-    char **names = var_GetAllNames(VLC_OBJECT(filter));
-    if (names == NULL)
-        return;
-
-    for (char **pname = names; *pname != NULL; pname++)
-    {
-        char *name = *pname;
-        int var_type = var_Type(filter, name);
-        if ((var_type & VLC_VAR_ISCOMMAND))
-        {
-            assert(var_Type(vout, name) == 0);
-            var_Create(vout, name, var_type | VLC_VAR_DOINHERIT);
-            var_AddCallback(vout, name, FilterProxyCallback, filter);
-        }
-        free(name);
-    }
-    free(names);
-}
-
 static int ThreadDelFilterCallbacks(filter_t *filter, void *opaque)
 {
-    vout_thread_t *vout = opaque;
-    char **names = var_GetAllNames(VLC_OBJECT(filter));
-    if (names == NULL)
-        return VLC_SUCCESS;
-
-    for (char **pname = names; *pname != NULL; pname++)
-    {
-        char *name = *pname;
-        int var_type = var_Type(filter, name);
-        if ((var_type & VLC_VAR_ISCOMMAND))
-        {
-            var_DelCallback(vout, name, FilterProxyCallback, filter);
-            var_Destroy(vout, name);
-        }
-        free(name);
-    }
-    free(names);
+    filter_DelProxyCallbacks((vlc_object_t *)opaque, filter,
+                             FilterRestartCallback);
     return VLC_SUCCESS;
 }
 
@@ -843,7 +804,7 @@ static void ThreadChangeFilters(vout_thread_t *vout,
                 config_ChainDestroy(e->cfg);
             }
             else if (a == 1) /* Add callbacks for interactive filters */
-                ThreadAddFilterCallbacks(vout, filter);
+                filter_AddProxyCallbacks(vout, filter, FilterRestartCallback);
 
             free(e->name);
             free(e);
@@ -1651,7 +1612,10 @@ static int ThreadControl(vout_thread_t *vout, vout_control_cmd_t cmd)
         ThreadDisplayOsdTitle(vout, cmd.u.string);
         break;
     case VOUT_CONTROL_CHANGE_FILTERS:
-        ThreadChangeFilters(vout, NULL, cmd.u.string, -1, false);
+        ThreadChangeFilters(vout, NULL,
+                            cmd.u.string != NULL ?
+                            cmd.u.string : vout->p->filter.configuration,
+                            -1, false);
         break;
     case VOUT_CONTROL_CHANGE_INTERLACE:
         ThreadChangeFilters(vout, NULL, vout->p->filter.configuration,
